@@ -91,5 +91,21 @@ func All() []plugin.MigrationScript {
 		new(tasksUsesJSON),
 		new(modifyCicdPipelinesToText),
 		new(dropTapStateTable),
+		new(addCICDDeploymentsTable),
+		new(normalizeBpSettings),
+		new(addSyncPolicy),
+		new(addIssueCustomArrayField),
+		new(removePositionFromPullRequestComments),
+		new(changeDurationSecToFloat64),
+		new(addSomeDateFieldsToDevopsTables),
+		new(addOriginalStatusAndResultToDevOpsTables),
+		new(addQueuedDurationSecFieldToDevopsTables),
+		new(addCommitMsgtoDeploymentCommit),
+		new(modifyIssueOriginalTypeLength),
+		new(addCommitMsgtoPipelineCommit),
+		new(modfiyFieldsSort),
+		new(modifyIssueLeadTimeMinutesToUint),
+		new(addUrgencyToIssues),
+		new(addSubtabknameToDeployment),
 	}
 }
