@@ -20,6 +20,7 @@ package runner
 import (
 	gocontext "context"
 	"fmt"
+	"strings"
 	"time"
 
 	"github.com/apache/incubator-devlake/core/context"
@@ -53,6 +54,7 @@ func RunTask(
 	if err := db.First(dbPipeline, dal.Where("id = ? ", task.PipelineId)); err != nil {
 		return err
 	}
+
 	logger, err := getTaskLogger(basicRes.GetLogger(), task)
 	if err != nil {
 		return err
@@ -106,14 +108,11 @@ func RunTask(
 			}
 		}
 		// update finishedTasks
-		dbe := db.UpdateColumn(
+		errors.Must(db.UpdateColumn(
 			&models.Pipeline{},
 			"finished_tasks", dal.Expr("finished_tasks + 1"),
 			dal.Where("id=?", task.PipelineId),
-		)
-		if dbe != nil {
-			logger.Error(dbe, "update pipeline state failed")
-		}
+		))
 		// not return err if the `SkipOnFail` is true and the error is not canceled
 		if dbPipeline.SkipOnFail && !errors.Is(err, gocontext.Canceled) {
 			err = nil
@@ -136,6 +135,7 @@ func RunTask(
 		basicRes.ReplaceLogger(logger),
 		task,
 		progress,
+		&dbPipeline.SyncPolicy,
 	)
 	return err
 }
@@ -146,6 +146,7 @@ func RunPluginTask(
 	basicRes context.BasicRes,
 	task *models.Task,
 	progress chan plugin.RunningProgress,
+	syncPolicy *models.SyncPolicy,
 ) errors.Error {
 	pluginMeta, err := plugin.GetPlugin(task.Plugin)
 	if err != nil {
@@ -161,6 +162,7 @@ func RunPluginTask(
 		task,
 		pluginTask,
 		progress,
+		syncPolicy,
 	)
 }
 
@@ -171,6 +173,7 @@ func RunPluginSubTasks(
 	task *models.Task,
 	pluginTask plugin.PluginTask,
 	progress chan plugin.RunningProgress,
+	syncPolicy *models.SyncPolicy,
 ) errors.Error {
 	logger := basicRes.GetLogger()
 	logger.Info("start plugin")
@@ -212,8 +215,12 @@ func RunPluginSubTasks(
 		}
 	}
 
-	// make sure `Required` subtasks are always enabled
+	// 1. make sure `Collect` subtasks skip if `SkipCollectors` is true
+	// 2. make sure `Required` subtasks are always enabled
 	for _, subtaskMeta := range subtaskMetas {
+		if syncPolicy != nil && syncPolicy.SkipCollectors && strings.Contains(strings.ToLower(subtaskMeta.Name), "collect") {
+			subtasksFlag[subtaskMeta.Name] = false
+		}
 		if subtaskMeta.Required {
 			subtasksFlag[subtaskMeta.Name] = true
 		}
@@ -236,6 +243,7 @@ func RunPluginSubTasks(
 	if err != nil {
 		return errors.Default.Wrap(err, fmt.Sprintf("error preparing task data for %s", task.Plugin))
 	}
+	taskCtx.SetSyncPolicy(syncPolicy)
 	taskCtx.SetData(taskData)
 
 	// execute subtasks in order
