@@ -21,13 +21,13 @@ import (
 	"encoding/json"
 	"net/http"
 	"net/url"
+	"reflect"
 	"time"
 
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/models"
 	"github.com/apache/incubator-devlake/core/plugin"
-	"github.com/apache/incubator-devlake/helpers/pluginhelper/common"
 )
 
 // ApiCollectorStateManager save collector state in framework table
@@ -35,25 +35,58 @@ type ApiCollectorStateManager struct {
 	RawDataSubTaskArgs
 	// *ApiCollector
 	// *GraphqlCollector
-	subtasks     []plugin.SubTask
-	LatestState  models.CollectorLatestState
-	TimeAfter    *time.Time
-	ExecuteStart time.Time
+	subtasks      []plugin.SubTask
+	newState      models.CollectorLatestState
+	IsIncremental bool
+	Since         *time.Time
+	Before        *time.Time
+}
+
+type CollectorOptions struct {
+	TimeAfter string `json:"timeAfter,omitempty" mapstructure:"timeAfter"`
 }
 
 // NewStatefulApiCollector create a new ApiCollectorStateManager
-func NewStatefulApiCollector(args RawDataSubTaskArgs, timeAfter *time.Time) (*ApiCollectorStateManager, errors.Error) {
+func NewStatefulApiCollector(args RawDataSubTaskArgs) (*ApiCollectorStateManager, errors.Error) {
 	db := args.Ctx.GetDal()
-
+	syncPolicy := args.Ctx.TaskContext().SyncPolicy()
 	rawDataSubTask, err := NewRawDataSubTask(args)
 	if err != nil {
 		return nil, errors.Default.Wrap(err, "Couldn't resolve raw subtask args")
 	}
-	latestState := models.CollectorLatestState{}
-	err = db.First(&latestState, dal.Where(`raw_data_table = ? AND raw_data_params = ?`, rawDataSubTask.table, rawDataSubTask.params))
+
+	// get optionTimeAfter from options
+	data := args.Ctx.GetData()
+	value := reflect.ValueOf(data)
+	if value.Kind() == reflect.Ptr && value.Elem().Kind() == reflect.Struct {
+		options := value.Elem().FieldByName("Options")
+		if options.IsValid() && options.Kind() == reflect.Ptr && options.Elem().Kind() == reflect.Struct {
+			collectorOptions := options.Elem().FieldByName("CollectorOptions")
+			if collectorOptions.IsValid() && collectorOptions.Kind() == reflect.Struct {
+				timeAfter := collectorOptions.FieldByName("TimeAfter")
+				if timeAfter.IsValid() && timeAfter.Kind() == reflect.String && timeAfter.String() != "" {
+					optionTimeAfter, parseErr := time.Parse(time.RFC3339, timeAfter.String())
+					if parseErr != nil {
+						return nil, errors.Default.Wrap(parseErr, "Failed to parse timeAfter!")
+					}
+					if syncPolicy != nil {
+						syncPolicy.TimeAfter = &optionTimeAfter
+					} else {
+						syncPolicy = &models.SyncPolicy{
+							TimeAfter: &optionTimeAfter,
+						}
+					}
+				}
+			}
+		}
+	}
+
+	// CollectorLatestState retrieves the latest collector state from the database
+	oldState := models.CollectorLatestState{}
+	err = db.First(&oldState, dal.Where(`raw_data_table = ? AND raw_data_params = ?`, rawDataSubTask.table, rawDataSubTask.params))
 	if err != nil {
 		if db.IsErrorNotFound(err) {
-			latestState = models.CollectorLatestState{
+			oldState = models.CollectorLatestState{
 				RawDataTable:  rawDataSubTask.table,
 				RawDataParams: rawDataSubTask.params,
 			}
@@ -61,33 +94,63 @@ func NewStatefulApiCollector(args RawDataSubTaskArgs, timeAfter *time.Time) (*Ap
 			return nil, errors.Default.Wrap(err, "failed to load JiraLatestCollectorMeta")
 		}
 	}
+	// Extract timeAfter and latestSuccessStart from old state
+	oldTimeAfter := oldState.TimeAfter
+	oldLatestSuccessStart := oldState.LatestSuccessStart
+
+	// Calculate incremental and since based on syncPolicy and old state
+	var isIncremental bool
+	var since *time.Time
+
+	if oldLatestSuccessStart == nil {
+		// 1. If no oldState.LatestSuccessStart, not incremental and since is syncPolicy.TimeAfter
+		isIncremental = false
+		if syncPolicy != nil {
+			since = syncPolicy.TimeAfter
+		}
+	} else if syncPolicy == nil {
+		// 2. If no syncPolicy, incremental and since is oldState.LatestSuccessStart
+		isIncremental = true
+		since = oldLatestSuccessStart
+	} else if syncPolicy.FullSync {
+		// 3. If fullSync true, not incremental and since is syncPolicy.TimeAfter
+		isIncremental = false
+		since = syncPolicy.TimeAfter
+	} else if syncPolicy.TimeAfter == nil {
+		// 4. If no syncPolicy TimeAfter, incremental and since is oldState.LatestSuccessStart
+		isIncremental = true
+		since = oldLatestSuccessStart
+	} else {
+		// 5. If syncPolicy.TimeAfter not nil
+		if oldTimeAfter != nil && syncPolicy.TimeAfter.Before(*oldTimeAfter) {
+			// 4.1 If oldTimeAfter not nil and syncPolicy.TimeAfter before oldTimeAfter, incremental is false and since is syncPolicy.TimeAfter
+			isIncremental = false
+			since = syncPolicy.TimeAfter
+		} else {
+			// 4.2 If oldTimeAfter nil or syncPolicy.TimeAfter after oldTimeAfter, incremental is true and since is oldState.LatestSuccessStart
+			isIncremental = true
+			since = oldLatestSuccessStart
+		}
+	}
+
+	currentTime := time.Now()
+	oldState.LatestSuccessStart = &currentTime
+	oldState.TimeAfter = syncPolicy.TimeAfter
+
 	return &ApiCollectorStateManager{
 		RawDataSubTaskArgs: args,
-		LatestState:        latestState,
-		TimeAfter:          timeAfter,
-		ExecuteStart:       time.Now(),
+		newState:           oldState,
+		IsIncremental:      isIncremental,
+		Since:              since,
+		Before:             &currentTime,
 	}, nil
-}
 
-// IsIncremental indicates if the collector should operate in incremental mode
-func (m *ApiCollectorStateManager) IsIncremental() bool {
-	prevSyncTime := m.LatestState.LatestSuccessStart
-	prevTimeAfter := m.LatestState.TimeAfter
-	currTimeAfter := m.TimeAfter
-
-	if prevSyncTime == nil {
-		return false
-	}
-	// if we cleared the timeAfter, or moved timeAfter back in time, we should do a full sync
-	if currTimeAfter != nil {
-		return prevTimeAfter == nil || !currTimeAfter.Before(*prevTimeAfter)
-	}
-	return prevTimeAfter == nil
 }
 
 // InitCollector init the embedded collector
 func (m *ApiCollectorStateManager) InitCollector(args ApiCollectorArgs) errors.Error {
 	args.RawDataSubTaskArgs = m.RawDataSubTaskArgs
+	args.Incremental = args.Incremental || m.IsIncremental
 	apiCollector, err := NewApiCollector(args)
 	if err != nil {
 		return err
@@ -99,6 +162,7 @@ func (m *ApiCollectorStateManager) InitCollector(args ApiCollectorArgs) errors.E
 // InitGraphQLCollector init the embedded collector
 func (m *ApiCollectorStateManager) InitGraphQLCollector(args GraphqlCollectorArgs) errors.Error {
 	args.RawDataSubTaskArgs = m.RawDataSubTaskArgs
+	args.Incremental = args.Incremental || m.IsIncremental
 	graphqlCollector, err := NewGraphqlCollector(args)
 	if err != nil {
 		return err
@@ -117,9 +181,7 @@ func (m *ApiCollectorStateManager) Execute() errors.Error {
 	}
 
 	db := m.Ctx.GetDal()
-	m.LatestState.LatestSuccessStart = &m.ExecuteStart
-	m.LatestState.TimeAfter = m.TimeAfter
-	return db.CreateOrUpdate(&m.LatestState)
+	return db.CreateOrUpdate(&m.newState)
 }
 
 // NewStatefulApiCollectorForFinalizableEntity aims to add timeFilter/diffSync support for
@@ -150,19 +212,13 @@ func NewStatefulApiCollectorForFinalizableEntity(args FinalizableApiCollectorArg
 		Options: args.Options,
 		Params:  args.Params,
 		Table:   args.Table,
-	}, args.TimeAfter)
+	})
 	if err != nil {
 		return nil, err
 	}
 
-	// // prepare the basic variables
-	var isIncremental = manager.IsIncremental()
-	var createdAfter *time.Time
-	if isIncremental {
-		createdAfter = manager.LatestState.LatestSuccessStart
-	} else {
-		createdAfter = manager.TimeAfter
-	}
+	createdAfter := manager.Since
+	isIncremental := manager.IsIncremental
 
 	// step 1: create a collector to collect newly added records
 	err = manager.InitCollector(ApiCollectorArgs{
@@ -227,7 +283,8 @@ func NewStatefulApiCollectorForFinalizableEntity(args FinalizableApiCollectorArg
 		return nil, err
 	}
 
-	if args.CollectUnfinishedDetails == nil {
+	syncPolicy := args.Ctx.TaskContext().SyncPolicy()
+	if args.CollectUnfinishedDetails == nil || (syncPolicy != nil && syncPolicy.FullSync) {
 		return manager, nil
 	}
 
@@ -281,7 +338,7 @@ type FinalizableApiCollectorCommonArgs struct {
 	Header          func(reqData *RequestData, createdAfter *time.Time) (http.Header, errors.Error) // optional, build header for the request
 	RequestBody     func(reqData *RequestData) map[string]interface{}                               // optional, build request body for the request if the Method set to POST or PUT
 	MinTickInterval *time.Duration                                                                  // optional, minimum interval between two requests, some endpoints might have a more conservative rate limit than others within the same instance, you can mitigate this by setting a higher MinTickInterval to override the connection level rate limit.
-	AfterResponse   common.ApiClientAfterResponse                                                   // optional, hook to run after each response, would be called before the ResponseParser
+	AfterResponse   plugin.ApiClientAfterResponse                                                   // optional, hook to run after each response, would be called before the ResponseParser
 	ResponseParser  func(res *http.Response) ([]json.RawMessage, errors.Error)                      // required, parse the response body and return a list of entities
 }
 
