@@ -138,8 +138,13 @@ func (collector *GraphqlCollector) Execute() errors.Error {
 
 	divider := NewBatchSaveDivider(collector.args.Ctx, collector.args.BatchSize, collector.table, collector.params)
 
+	isIncremental := collector.args.Incremental
+	syncPolicy := collector.args.Ctx.TaskContext().SyncPolicy()
+	if syncPolicy != nil && syncPolicy.FullSync {
+		isIncremental = false
+	}
 	// flush data if not incremental collection
-	if collector.args.Incremental {
+	if isIncremental {
 		// re extract data for new scope config
 		err = collector.ExtractExistRawData(divider)
 		if err != nil {
@@ -304,9 +309,8 @@ func (collector *GraphqlCollector) ExtractExistRawData(divider *BatchSaveDivider
 	}
 	logger.Info("get data from %s where params=%s and got %d", collector.table, collector.params, count)
 	defer cursor.Close()
-	row := &RawData{}
 
-	// prgress
+	// progress
 	collector.args.Ctx.SetProgress(0, -1)
 	ctx := collector.args.Ctx.GetContext()
 	// iterate all rows
@@ -318,6 +322,7 @@ func (collector *GraphqlCollector) ExtractExistRawData(divider *BatchSaveDivider
 		}
 		// get the type of query and variables. For each iteration, the query should be a different object
 		query, variables, _ := collector.args.BuildQuery(nil)
+		row := &RawData{}
 		err = db.Fetch(cursor, row)
 		if err != nil {
 			return errors.Default.Wrap(err, "error fetching row")
