@@ -18,13 +18,17 @@ limitations under the License.
 package api
 
 import (
+	gocontext "context"
 	"encoding/base64"
 	"encoding/json"
 	"fmt"
-	"github.com/apache/incubator-devlake/core/log"
+	"io"
 	"net/http"
+	"net/url"
 	"strconv"
 
+	"github.com/apache/incubator-devlake/core/log"
+
 	"github.com/apache/incubator-devlake/core/context"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/plugin"
@@ -65,10 +69,11 @@ type SearchRemoteScopesOutput struct {
 
 // RemoteApiHelper is used to write the CURD of connection
 type RemoteApiHelper[Conn plugin.ApiConnection, Scope plugin.ToolLayerScope, ApiScope plugin.ApiScope, Group plugin.ApiGroup] struct {
-	basicRes   context.BasicRes
-	validator  *validator.Validate
-	connHelper *ConnectionApiHelper
-	logger     log.Logger
+	basicRes        context.BasicRes
+	validator       *validator.Validate
+	connHelper      *ConnectionApiHelper
+	httpClientCache map[string]*ApiClient
+	logger          log.Logger
 }
 
 // NewRemoteHelper creates a ScopeHelper for connection management
@@ -84,10 +89,11 @@ func NewRemoteHelper[Conn plugin.ApiConnection, Scope plugin.ToolLayerScope, Api
 		return nil
 	}
 	return &RemoteApiHelper[Conn, Scope, ApiScope, Group]{
-		basicRes:   basicRes,
-		validator:  vld,
-		connHelper: connHelper,
-		logger:     basicRes.GetLogger(),
+		basicRes:        basicRes,
+		validator:       vld,
+		connHelper:      connHelper,
+		httpClientCache: make(map[string]*ApiClient),
+		logger:          basicRes.GetLogger(),
 	}
 }
 
@@ -122,6 +128,52 @@ const (
 	TypeMixed string = "mixed"
 )
 
+func (r *RemoteApiHelper[Conn, Scope, ApiScope, Group]) GetApiClient(connection plugin.CacheableConnection) (*ApiClient, errors.Error) {
+	key := connection.GetHash()
+	// empty key means no connection reuse
+	if key == "" {
+		r.logger.Info("No api client reuse")
+		return NewApiClientFromConnection(gocontext.TODO(), r.basicRes, connection)
+	}
+
+	if client, ok := r.httpClientCache[key]; ok {
+		r.logger.Info("Reused api client")
+		return client, nil
+	}
+	r.logger.Info("Creating new api client")
+	newClient, err := NewApiClientFromConnection(gocontext.TODO(), r.basicRes, connection)
+	if err != nil {
+		return nil, err
+	}
+	r.httpClientCache[key] = newClient
+	return newClient, nil
+}
+
+func (r *RemoteApiHelper[Conn, Scope, ApiScope, Group]) ProxyApiGet(conn plugin.CacheableConnection, path string, query url.Values) (*plugin.ApiResourceOutput, errors.Error) {
+	apiClient, err := r.GetApiClient(conn)
+	if err != nil {
+		return nil, err
+	}
+
+	resp, err := apiClient.Get(path, query, nil)
+	if err != nil {
+		return nil, err
+	}
+	defer resp.Body.Close()
+
+	body, err := errors.Convert01(io.ReadAll(resp.Body))
+	if err != nil {
+		return nil, err
+	}
+	// verify response body is json
+	var tmp interface{}
+	err = errors.Convert(json.Unmarshal(body, &tmp))
+	if err != nil {
+		return nil, err
+	}
+	return &plugin.ApiResourceOutput{Status: resp.StatusCode, Body: json.RawMessage(body)}, nil
+}
+
 // PrepareFirstPageToken prepares the first page token
 func (r *RemoteApiHelper[Conn, Scope, ApiScope, Group]) PrepareFirstPageToken(customInfo string) (*plugin.ApiResourceOutput, errors.Error) {
 	outputBody := &FirstPageTokenOutput{}
