@@ -18,7 +18,6 @@ limitations under the License.
 package api
 
 import (
-	"encoding/json"
 	"fmt"
 	"reflect"
 	"strconv"
@@ -36,7 +35,6 @@ import (
 	"github.com/apache/incubator-devlake/helpers/dbhelper"
 	serviceHelper "github.com/apache/incubator-devlake/helpers/pluginhelper/services"
 	"github.com/go-playground/validator/v10"
-	"github.com/mitchellh/mapstructure"
 )
 
 type NoScopeConfig struct{}
@@ -64,8 +62,9 @@ type (
 	// Alias, for swagger purposes
 	ScopeRefDoc                                            = serviceHelper.BlueprintProjectPairs
 	ScopeRes[Scope plugin.ToolLayerScope, ScopeConfig any] struct {
-		Scope                    Scope                    `mapstructure:",squash"` // ideally we need this field to be embedded in the struct
-		ScopeResDoc[ScopeConfig] `mapstructure:",squash"` // however, only this type of embeding is supported as of golang 1.20
+		Scope       Scope               `mapstructure:"scope,omitempty" json:"scope,omitempty"`
+		ScopeConfig *ScopeConfig        `mapstructure:"scopeConfig,omitempty" json:"scopeConfig,omitempty"`
+		Blueprints  []*models.Blueprint `mapstructure:"blueprints,omitempty" json:"blueprints,omitempty"`
 	}
 	ScopeListRes[Scope plugin.ToolLayerScope, ScopeConfig any] struct {
 		Scopes []*ScopeRes[Scope, ScopeConfig] `mapstructure:"scopes" json:"scopes"`
@@ -209,7 +208,7 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) UpdateScope(input *pl
 	if err != nil {
 		return nil, err
 	}
-	err = DecodeMapStruct(input.Body, scope, false)
+	err = DecodeMapStruct(input.Body, scope, true)
 	if err != nil {
 		return nil, errors.Default.Wrap(err, "patch scope error")
 	}
@@ -248,26 +247,8 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) GetScopes(input *plug
 	}
 	// return empty array rather than nil in case of no scopes
 	if len(apiScopes) > 0 && params.loadBlueprints {
-		// fetch blueprints for all scopes in one call since all bps must be loaded to determine which ones are associated with the scopes
-		// TODO: split bp.settings into separate tables and load only the ones needed
-		var scopeIds []string
 		for _, apiScope := range apiScopes {
-			// scopeId := fmt.Sprintf("%v", reflectField(apiScope.Scope, gs.reflectionParams.ScopeIdFieldName).Interface())
-			scopeIds = append(scopeIds, apiScope.Scope.ScopeId())
-		}
-		blueprintMap := errors.Must1(gs.bpManager.GetBlueprintsByScopes(params.connectionId, params.plugin, scopeIds...))
-		for _, apiScope := range apiScopes {
-			if bps, ok := blueprintMap[apiScope.Scope.ScopeId()]; ok {
-				apiScope.Blueprints = bps
-				delete(blueprintMap, apiScope.Scope.ScopeId())
-			}
-		}
-		if len(blueprintMap) > 0 {
-			var danglingIds []string
-			for bpId := range blueprintMap {
-				danglingIds = append(danglingIds, bpId)
-			}
-			gs.log.Warn(nil, "The following dangling scopes were found: %v", danglingIds)
+			apiScope.Blueprints = gs.bpManager.GetBlueprintsByScopeId(params.connectionId, params.plugin, apiScope.Scope.ScopeId())
 		}
 	}
 	return &ScopeListRes[Scope, ScopeConfig]{
@@ -295,13 +276,7 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) GetScope(input *plugi
 	}
 	scopeRes := apiScopes[0]
 	if params.loadBlueprints {
-		blueprintMap, err := gs.bpManager.GetBlueprintsByScopes(params.connectionId, params.plugin, params.scopeId)
-		if err != nil {
-			return nil, errors.Default.Wrap(err, fmt.Sprintf("error getting blueprints for scope with scope ID %s", params.scopeId))
-		}
-		if len(blueprintMap) == 1 {
-			scopeRes.Blueprints = blueprintMap[params.scopeId]
-		}
+		scopeRes.Blueprints = gs.bpManager.GetBlueprintsByScopeId(params.connectionId, params.plugin, params.scopeId)
 	}
 	return scopeRes, nil
 }
@@ -338,9 +313,12 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) DeleteScope(input *pl
 	}
 
 	if !params.deleteDataOnly {
-		if refs, err := gs.getScopeReferences(params.connectionId, params.scopeId); err != nil || refs != nil {
-			if err != nil {
-				return nil, err
+		blueprints := gs.bpManager.GetBlueprintsByScopeId(params.connectionId, params.plugin, params.scopeId)
+		if len(blueprints) > 0 {
+			refs = &serviceHelper.BlueprintProjectPairs{}
+			for _, bp := range blueprints {
+				refs.Blueprints = append(refs.Blueprints, bp.Name)
+				refs.Projects = append(refs.Projects, bp.ProjectName)
 			}
 			return refs, errors.Conflict.New("Found one or more references to this scope")
 		}
@@ -373,18 +351,6 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) addScopeConfig(scopes
 	return apiScopes, nil
 }
 
-func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) getScopeReferences(connectionId uint64, scopeId string) (*serviceHelper.BlueprintProjectPairs, errors.Error) {
-	blueprintMap, err := gs.bpManager.GetBlueprintsByScopes(connectionId, gs.plugin, scopeId)
-	if err != nil {
-		return nil, err
-	}
-	blueprints := blueprintMap[scopeId]
-	if len(blueprints) == 0 {
-		return nil, nil
-	}
-	return serviceHelper.NewBlueprintProjectPairs(blueprints), nil
-}
-
 func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) extractFromReqParam(input *plugin.ApiResourceInput, withScopeId bool) (*requestParams, errors.Error) {
 	connectionId, err := strconv.ParseUint(input.Params["connectionId"], 10, 64)
 	if err != nil {
@@ -634,20 +600,25 @@ func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) transactionalDelete(t
 	return nil
 }
 
-// Implement MarshalJSON method to flatten all fields
-func (sr *ScopeRes[T, Y]) MarshalJSON() ([]byte, error) {
-	var flatMap map[string]interface{}
-	err := mapstructure.Decode(sr, &flatMap)
+// GetScopeLatestSyncState only works for remote plugins.
+// Make sure all remote plugins save their state in table `_devlake_collector_latest_state`.
+// For golang version plugin, use `dsHelper.ScopeApi.GetScopeLatestSyncState` instead.
+func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) GetScopeLatestSyncState(input *plugin.ApiResourceInput) ([]*models.LatestSyncState, errors.Error) {
+	scope, err := gs.GetScope(input)
 	if err != nil {
 		return nil, err
 	}
-	// Encode the flattened map to JSON
-	result, err := json.Marshal(flatMap)
-	if err != nil {
+	params := plugin.MarshalScopeParams(scope.Scope.ScopeParams())
+	scopeSyncStates := []*models.LatestSyncState{}
+	if err := gs.db.All(
+		&scopeSyncStates,
+		dal.Select("raw_data_table, latest_success_start, raw_data_params"),
+		dal.From("_devlake_collector_latest_state"),
+		dal.Where("raw_data_params = ?", params),
+	); err != nil {
 		return nil, err
 	}
-
-	return result, nil
+	return scopeSyncStates, nil
 }
 
 func (gs *GenericScopeApiHelper[Conn, Scope, ScopeConfig]) getAffectedTables(pluginName string) ([]string, errors.Error) {
