@@ -65,21 +65,30 @@ func SearchRemoteScopes(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutp
 				return nil, errors.BadInput.Wrap(err, "failed to get create apiClient")
 			}
 			query := initialQuery(queryData)
+			if len(queryData.Search) == 0 {
+				return nil, errors.BadInput.New("empty search query")
+			}
 			query.Set("searchTerm", queryData.Search[0])
 			// request search
 			res, err := apiClient.Get("search/plans.json", query, nil)
 			if err != nil {
 				return nil, err
 			}
+
 			resBody := models.ApiBambooSearchPlanResponse{}
 			err = api.UnmarshalResponse(res, &resBody)
 			if err != nil {
 				return nil, err
 			}
+
 			var apiBambooPlans []models.ApiBambooPlan
 			// append project to output
 			for _, apiResult := range resBody.SearchResults {
-				apiBambooPlans = append(apiBambooPlans, apiResult.Entity)
+				bambooPlan := models.ApiBambooPlan{
+					Key:  apiResult.SearchEntity.Key,
+					Name: apiResult.SearchEntity.Name(),
+				}
+				apiBambooPlans = append(apiBambooPlans, bambooPlan)
 			}
 			return apiBambooPlans, err
 		})
@@ -96,7 +105,7 @@ func Proxy(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Er
 
 func initialQuery(queryData *api.RemoteQueryData) url.Values {
 	query := url.Values{}
-	query.Set("showEmpty", fmt.Sprintf("%v", true))
+	query.Set("showEmpty", fmt.Sprintf("%v", false))
 	query.Set("max-result", fmt.Sprintf("%v", queryData.PerPage))
 	query.Set("start-index", fmt.Sprintf("%v", (queryData.Page-1)*queryData.PerPage))
 	return query
