@@ -31,23 +31,24 @@ func TestBambooDeployDataFlow(t *testing.T) {
 	dataflowTester := e2ehelper.NewDataFlowTester(t, "bamboo", bamboo)
 	taskData := &tasks.BambooTaskData{
 		Options: &models.BambooOptions{
-			ConnectionId:      3,
-			ProjectKey:        "TEST1",
+			ConnectionId:      1,
+			PlanKey:           "TEST1",
 			BambooScopeConfig: new(models.BambooScopeConfig),
 		},
+		ApiClient: getFakeAPIClient(),
 	}
 
 	// import raw data table
-	dataflowTester.ImportCsvIntoRawTable("./raw_tables/_raw_bamboo_api_deploy.csv", "_raw_bamboo_api_deploy")
-	// it need import plan data
-	dataflowTester.ImportCsvIntoTabler("./raw_tables/_tool_bamboo_plans_for_deploy.csv", models.BambooPlan{})
+	dataflowTester.ImportCsvIntoRawTable("./raw_tables/_raw_bamboo_api_deploys.csv", "_raw_bamboo_api_deploys")
+	// it needs import plan data
+	//dataflowTester.ImportCsvIntoTabler("./raw_tables/_tool_bamboo_plans_for_deploys.csv", models.BambooPlan{})
 
 	// verify extraction
 	dataflowTester.FlushTabler(&models.BambooDeployEnvironment{})
 	dataflowTester.Subtask(tasks.ExtractDeployMeta, taskData)
 	dataflowTester.VerifyTable(
 		models.BambooDeployEnvironment{},
-		"./snapshot_tables/_tool_bamboo_deploy_environment.csv",
+		"./snapshot_tables/_tool_bamboo_deploy_environments.csv",
 		e2ehelper.ColumnWithRawData(
 			"connection_id",
 			"env_id",
