@@ -17,6 +17,8 @@ limitations under the License.
 
 package models
 
+import "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
+
 type BambooApiParams struct {
 	ConnectionId uint64 `json:"connectionId"`
 	PlanKey      string
@@ -27,9 +29,10 @@ type BambooOptions struct {
 	// options means some custom params required by plugin running.
 	// Such As How many rows do your want
 	// You can use it in sub tasks and you need pass it in main.go and pipelines.
-	ConnectionId       uint64   `json:"connectionId"`
-	PlanKey            string   `json:"planKey"`
-	Tasks              []string `json:"tasks,omitempty"`
-	ScopeConfigId      uint64   `mapstructure:"scopeConfigId" json:"scopeConfigId"`
-	*BambooScopeConfig `mapstructure:"scopeConfig" json:"scopeConfig"`
+	ConnectionId         uint64   `json:"connectionId"`
+	PlanKey              string   `json:"planKey"`
+	Tasks                []string `json:"tasks,omitempty"`
+	ScopeConfigId        uint64   `mapstructure:"scopeConfigId" json:"scopeConfigId"`
+	*BambooScopeConfig   `mapstructure:"scopeConfig" json:"scopeConfig"`
+	api.CollectorOptions `mapstructure:",squash"`
 }
