@@ -18,8 +18,6 @@ limitations under the License.
 package tasks
 
 import (
-	"reflect"
-
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/models/domainlayer"
@@ -28,6 +26,8 @@ import (
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 	"github.com/apache/incubator-devlake/plugins/bamboo/models"
+	"reflect"
+	"time"
 )
 
 var ConvertPlanBuildsMeta = plugin.SubTaskMeta{
@@ -61,25 +61,32 @@ func ConvertPlanBuilds(taskCtx plugin.SubTaskContext) errors.Error {
 			if line.BuildStartedTime == nil {
 				return nil, nil
 			}
+			createdDate := time.Now()
+			if line.BuildStartedTime != nil {
+				createdDate = *line.BuildStartedTime
+			}
 			domainPlanBuild := &devops.CICDPipeline{
 				DomainEntity: domainlayer.DomainEntity{Id: planBuildIdGen.Generate(data.Options.ConnectionId, line.PlanBuildKey)},
 				Name:         line.GenerateCICDPipeLineName(),
-				DurationSec:  uint64(line.BuildDurationInSeconds),
-				CreatedDate:  *line.BuildStartedTime,
-				FinishedDate: line.BuildCompletedDate,
-				CicdScopeId:  planIdGen.Generate(data.Options.ConnectionId, data.Options.PlanKey),
-
+				DurationSec:  float64(line.BuildDuration / 1e3),
+				TaskDatesInfo: devops.TaskDatesInfo{
+					CreatedDate:  createdDate,
+					StartedDate:  line.BuildStartedTime,
+					FinishedDate: line.BuildCompletedDate,
+				},
+				CicdScopeId: planIdGen.Generate(data.Options.ConnectionId, data.Options.PlanKey),
 				Result: devops.GetResult(&devops.ResultRule{
-					Failed:  []string{"Failed"},
-					Success: []string{"Successful"},
-					Default: line.BuildState,
+					Success: []string{ResultSuccess, ResultSuccessful},
+					Failure: []string{ResultFailed},
+					Default: devops.RESULT_DEFAULT,
 				}, line.BuildState),
-
-				Status: devops.GetStatus(&devops.StatusRule[string]{
-					Done:       []string{"Finished", "FINISHED"},
-					NotStarted: []string{"not_built", "NOT_BUILT", "Not_Built", "PENDING", "QUEUED"},
-					Default:    devops.STATUS_IN_PROGRESS,
+				OriginalResult: line.BuildState,
+				Status: devops.GetStatus(&devops.StatusRule{
+					Done:       []string{StatusFinished},
+					InProgress: []string{StatusInProgress, StatusPending, StatusQueued},
+					Default:    devops.STATUS_OTHER,
 				}, line.LifeCycleState),
+				OriginalStatus: line.LifeCycleState,
 			}
 
 			domainPlanBuild.Type = line.Type
