@@ -18,8 +18,12 @@ limitations under the License.
 package api
 
 import (
+	"database/sql"
+	"github.com/apache/incubator-devlake/core/dal"
+	"gorm.io/gorm/migrator"
 	"testing"
 
+	coreModels "github.com/apache/incubator-devlake/core/models"
 	"github.com/apache/incubator-devlake/core/models/common"
 	"github.com/apache/incubator-devlake/core/models/domainlayer"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/code"
@@ -62,27 +66,27 @@ func TestMakeDataSourcePipelinePlanV200(t *testing.T) {
 	// Refresh Global Variables and set the sql mock
 	mockBasicRes(t)
 
-	bs := &plugin.BlueprintScopeV200{
-		Id: "1",
+	bs := &coreModels.BlueprintScope{
+		ScopeId: "1",
 	}
-	bpScopes := make([]*plugin.BlueprintScopeV200, 0)
+	bpScopes := make([]*coreModels.BlueprintScope, 0)
 	bpScopes = append(bpScopes, bs)
-	syncPolicy := &plugin.BlueprintSyncPolicy{}
 
-	plan := make(plugin.PipelinePlan, len(bpScopes))
-	plan, err = makeDataSourcePipelinePlanV200(nil, plan, bpScopes, connection, syncPolicy)
+	plan := make(coreModels.PipelinePlan, len(bpScopes))
+	plan, err = makeDataSourcePipelinePlanV200(nil, plan, bpScopes, connection)
 	assert.Nil(t, err)
 	scopes, err := makeScopesV200(bpScopes, connection)
 	assert.Nil(t, err)
 
-	expectPlan := plugin.PipelinePlan{
-		plugin.PipelineStage{
+	expectPlan := coreModels.PipelinePlan{
+		coreModels.PipelineStage{
 			{
 				Plugin:   "bitbucket",
 				Subtasks: []string{},
 				Options: map[string]interface{}{
 					"fullName":     "likyh/likyhphp",
 					"connectionId": uint64(1),
+					"timeAfter":    "",
 				},
 			},
 			{
@@ -95,7 +99,7 @@ func TestMakeDataSourcePipelinePlanV200(t *testing.T) {
 				},
 			},
 		},
-		plugin.PipelineStage{
+		coreModels.PipelineStage{
 			{
 				Plugin: "refdiff",
 				Options: map[string]interface{}{
@@ -133,11 +137,13 @@ func TestMakeDataSourcePipelinePlanV200(t *testing.T) {
 
 func mockBasicRes(t *testing.T) {
 	testBitbucketRepo := &models.BitbucketRepo{
-		ConnectionId:  1,
-		BitbucketId:   "likyh/likyhphp",
-		Name:          "test/testRepo",
-		CloneUrl:      "https://this_is_cloneUrl",
-		ScopeConfigId: 1,
+		Scope: common.Scope{
+			ConnectionId:  1,
+			ScopeConfigId: 1,
+		},
+		BitbucketId: "likyh/likyhphp",
+		Name:        "test/testRepo",
+		CloneUrl:    "https://this_is_cloneUrl",
 	}
 
 	testScopeConfig := &models.BitbucketScopeConfig{
@@ -146,8 +152,8 @@ func mockBasicRes(t *testing.T) {
 			Model: common.Model{
 				ID: 1,
 			},
+			Name: "Bitbucket scope config",
 		},
-		Name:            "Bitbucket scope config",
 		IssueStatusTodo: "new,open,wantfix",
 		Refdiff: map[string]interface{}{
 			"tagsPattern": "pattern",
@@ -155,6 +161,15 @@ func mockBasicRes(t *testing.T) {
 			"tagsOrder":   "reverse semver",
 		},
 	}
+	var testColumTypes = []dal.ColumnMeta{
+		migrator.ColumnType{
+			NameValue: sql.NullString{
+				String: "abc",
+				Valid:  true,
+			},
+		},
+	}
+
 	// Refresh Global Variables and set the sql mock
 	mockRes := unithelper.DummyBasicRes(func(mockDal *mockdal.Dal) {
 		mockDal.On("First", mock.AnythingOfType("*models.BitbucketRepo"), mock.Anything).Run(func(args mock.Arguments) {
@@ -166,6 +181,14 @@ func mockBasicRes(t *testing.T) {
 			dst := args.Get(0).(*models.BitbucketScopeConfig)
 			*dst = *testScopeConfig
 		}).Return(nil)
+		mockDal.On("GetPrimarykeyColumns", mock.AnythingOfType("*models.BitbucketConnection"), mock.Anything).Run(nil).Return(
+			testColumTypes, nil)
+		mockDal.On("GetColumns", mock.AnythingOfType("models.BitbucketConnection"), mock.Anything).Run(nil).Return(
+			testColumTypes, nil)
+		mockDal.On("GetColumns", mock.AnythingOfType("models.BitbucketRepo"), mock.Anything).Run(nil).Return(
+			testColumTypes, nil)
+		mockDal.On("GetColumns", mock.AnythingOfType("models.BitbucketScopeConfig"), mock.Anything).Run(nil).Return(
+			testColumTypes, nil)
 	})
 	p := mockplugin.NewPluginMeta(t)
 	p.On("Name").Return("dummy").Maybe()
