@@ -82,6 +82,15 @@ func GetScopeList(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, er
 	return scopeHelper.GetScopeList(input)
 }
 
+func GetScopeDispatcher(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
+	scopeIdWithSuffix := strings.TrimLeft(input.Params["scopeId"], "/")
+	if strings.HasSuffix(scopeIdWithSuffix, "/latest-sync-state") {
+		input.Params["scopeId"] = strings.TrimSuffix(scopeIdWithSuffix, "/latest-sync-state")
+		return GetScopeLatestSyncState(input)
+	}
+	return GetScope(input)
+}
+
 // GetScope get one repo
 // @Summary get one repo
 // @Description get one repo
@@ -102,7 +111,7 @@ func GetScope(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors
 // @Description delete data associated with plugin scope
 // @Tags plugins/bitbucket
 // @Param connectionId path int true "connection ID"
-// @Param scopeId path int true "scope ID"
+// @Param scopeId path string true "scope ID"
 // @Param delete_data_only query bool false "Only delete the scope data, not the scope itself"
 // @Success 200
 // @Failure 400  {object} shared.ApiBody "Bad Request"
@@ -110,5 +119,6 @@ func GetScope(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors
 // @Failure 500  {object} shared.ApiBody "Internal Error"
 // @Router /plugins/bitbucket/connections/{connectionId}/scopes/{scopeId} [DELETE]
 func DeleteScope(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
+	input.Params["scopeId"] = strings.TrimLeft(input.Params["scopeId"], "/")
 	return scopeHelper.Delete(input)
 }
