@@ -18,6 +18,7 @@ limitations under the License.
 package e2e
 
 import (
+	"github.com/apache/incubator-devlake/core/models/domainlayer/devops"
 	"testing"
 
 	"github.com/apache/incubator-devlake/helpers/e2ehelper"
@@ -40,16 +41,14 @@ func TestDeloymentsDataFlow(t *testing.T) {
 			},
 		},
 	}
-
 	// import raw data table
 	dataflowTester.ImportCsvIntoRawTable("./raw_tables/_raw_bitbucket_api_deployments.csv", "_raw_bitbucket_api_deployments")
-
 	dataflowTester.FlushTabler(&models.BitbucketDeployment{})
 	// verify extraction
 	dataflowTester.Subtask(tasks.ExtractApiDeploymentsMeta, taskData)
 	dataflowTester.VerifyTable(
 		models.BitbucketDeployment{},
-		"./snapshot_tables/_tool_bitbucket_deployments.csv",
+		"./snapshot_tables/_tool_bitbucket_deployments_for_deployment.csv",
 		e2ehelper.ColumnWithRawData(
 			"connection_id",
 			"bitbucket_id",
@@ -71,4 +70,41 @@ func TestDeloymentsDataFlow(t *testing.T) {
 			//"key",
 		),
 	)
+
+	// verify conversion
+	dataflowTester.FlushTabler(&models.BitbucketRepo{})
+	dataflowTester.FlushTabler(&models.BitbucketPipeline{})
+	dataflowTester.FlushTabler(&models.BitbucketDeployment{})
+	dataflowTester.ImportCsvIntoTabler("./snapshot_tables/_tool_bitbucket_repos_for_deployment.csv", &models.BitbucketRepo{})
+	dataflowTester.ImportCsvIntoTabler("./snapshot_tables/_tool_bitbucket_pipelines_for_deployment.csv", &models.BitbucketPipeline{})
+	dataflowTester.ImportCsvIntoTabler("./snapshot_tables/_tool_bitbucket_deployments_for_deployment.csv", &models.BitbucketDeployment{})
+	dataflowTester.FlushTabler(&devops.CicdDeploymentCommit{})
+	dataflowTester.FlushTabler(&devops.CICDDeployment{})
+	dataflowTester.Subtask(tasks.ConvertiDeploymentMeta, taskData)
+	dataflowTester.VerifyTable(
+		devops.CicdDeploymentCommit{},
+		"./snapshot_tables/cicd_deployment_commits_for_deployment.csv",
+		[]string{
+			"id",
+			"name",
+			"result",
+			"status",
+			"original_result",
+			"original_status",
+			"environment",
+		},
+	)
+	dataflowTester.VerifyTable(
+		devops.CICDDeployment{},
+		"./snapshot_tables/cicd_deployments_for_deployment.csv",
+		[]string{
+			"id",
+			"name",
+			"result",
+			"status",
+			"original_result",
+			"original_status",
+			"environment",
+		},
+	)
 }
