@@ -30,6 +30,8 @@ import (
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
+const DORAGenerateDeploymentCommits = "dora.generateDeploymentCommits"
+
 var DeploymentCommitsGeneratorMeta = plugin.SubTaskMeta{
 	Name:             "generateDeploymentCommits",
 	EntryPoint:       GenerateDeploymentCommits,
@@ -43,7 +45,11 @@ type pipelineCommitEx struct {
 	PipelineName       string
 	Result             string
 	Status             string
-	DurationSec        *uint64
+	OriginalStatus     string
+	OriginalResult     string
+	DurationSec        *float64
+	QueuedDurationSec  *float64
+	StartedDate        *time.Time
 	CreatedDate        *time.Time
 	FinishedDate       *time.Time
 	Environment        string
@@ -58,46 +64,75 @@ func GenerateDeploymentCommits(taskCtx plugin.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*DoraTaskData)
 	// select all cicd_pipeline_commits from all "Deployments" in the project
 	// Note that failed records shall be included as well
-	cursor, err := db.Cursor(
+	noneSkippedResult := []string{devops.RESULT_FAILURE, devops.RESULT_SUCCESS}
+	var clauses = []dal.Clause{
 		dal.Select(
 			`
-				pc.*, p.name as pipeline_name,
+				pc.*,
+				p.name as pipeline_name,
 				p.result,
 				p.status,
 				p.duration_sec,
+				p.queued_duration_sec,
+				p.started_date,
 				p.created_date,
 				p.finished_date,
 				p.environment,
 				p.cicd_scope_id,
-				EXISTS(SELECT 1 FROM cicd_tasks t WHERE t.pipeline_id = p.id AND t.environment = ? AND t.result <> ?)
-				as has_testing_tasks,
-				EXISTS(SELECT 1 FROM cicd_tasks t WHERE t.pipeline_id = p.id AND t.environment = ? AND t.result <> ?)
-				as has_staging_tasks,
-				EXISTS( SELECT 1 FROM cicd_tasks t WHERE t.pipeline_id = p.id AND t.environment = ? AND t.result <> ?)
-				as has_production_tasks
+				p.original_status,
+				p.original_result,
+				EXISTS(SELECT 1 FROM cicd_tasks t WHERE t.pipeline_id = p.id AND t.environment = ? AND t.result IN ?) as has_testing_tasks,
+				EXISTS(SELECT 1 FROM cicd_tasks t WHERE t.pipeline_id = p.id AND t.environment = ? AND t.result IN ?) as has_staging_tasks,
+				EXISTS( SELECT 1 FROM cicd_tasks t WHERE t.pipeline_id = p.id AND t.environment = ? AND t.result IN ?) as has_production_tasks
 			`,
-			devops.TESTING, devops.RESULT_SKIPPED,
-			devops.STAGING, devops.RESULT_SKIPPED,
-			devops.PRODUCTION, devops.RESULT_SKIPPED,
+			devops.TESTING, noneSkippedResult,
+			devops.STAGING, noneSkippedResult,
+			devops.PRODUCTION, noneSkippedResult,
 		),
 		dal.From("cicd_pipeline_commits pc"),
 		dal.Join("LEFT JOIN cicd_pipelines p ON (p.id = pc.pipeline_id)"),
-		dal.Join("LEFT JOIN project_mapping pm ON (pm.table = 'cicd_scopes' AND pm.row_id = p.cicd_scope_id)"),
 		dal.Where(
 			`
-			pm.project_name = ? AND (
-				p.type = ? OR EXISTS(
-					SELECT 1 FROM cicd_tasks t WHERE t.pipeline_id = p.id AND t.type = ? AND t.result <> ?
-				)
-			) AND p.result <> ?
+			p.result IN ? AND (
+				p.type = ? OR EXISTS(SELECT 1 FROM cicd_tasks t WHERE t.pipeline_id = p.id AND t.type = ? AND t.result IN ?)
+			)
 			`,
-			data.Options.ProjectName,
+			noneSkippedResult,
 			devops.DEPLOYMENT,
 			devops.DEPLOYMENT,
-			devops.RESULT_SKIPPED,
-			devops.RESULT_SKIPPED,
+			noneSkippedResult,
 		),
-	)
+	}
+	if data.Options.ScopeId != nil {
+		clauses = append(clauses, dal.Where(`p.cicd_scope_id = ?`, data.Options.ScopeId))
+		// Clear previous results from the project
+		deleteSql := `DELETE FROM cicd_deployment_commits WHERE cicd_scope_id = ? and subtask_name = ?;`
+		err := db.Exec(deleteSql, data.Options.ScopeId, DORAGenerateDeploymentCommits)
+		if err != nil {
+			return errors.Default.Wrap(err, "error deleting previous cicd_deployment_commits")
+		}
+	} else {
+		clauses = append(clauses,
+			dal.Join("LEFT JOIN project_mapping pm ON (pm.table = 'cicd_scopes' AND pm.row_id = p.cicd_scope_id)"),
+			dal.Where(`pm.project_name = ?`, data.Options.ProjectName),
+		)
+		// Clear previous results from the project
+		deleteSql := `DELETE FROM cicd_deployment_commits
+			WHERE cicd_scope_id IN (
+			SELECT cicd_scope_id
+			FROM (
+				SELECT cdc.cicd_scope_id
+				FROM cicd_deployment_commits cdc
+				LEFT JOIN project_mapping pm ON (pm.table = 'cicd_scopes' AND pm.row_id = cdc.cicd_scope_id)
+				WHERE pm.project_name = ?
+			) AS subquery
+			) AND subtask_name = ?;`
+		err := db.Exec(deleteSql, data.Options.ProjectName, DORAGenerateDeploymentCommits)
+		if err != nil {
+			return errors.Default.Wrap(err, "error deleting previous cicd_deployment_commits")
+		}
+	}
+	cursor, err := db.Cursor(clauses...)
 	if err != nil {
 		return err
 	}
@@ -124,20 +159,29 @@ func GenerateDeploymentCommits(taskCtx plugin.SubTaskContext) errors.Error {
 				CicdDeploymentId: pipelineCommit.PipelineId,
 				Name:             pipelineCommit.PipelineName,
 				Result:           pipelineCommit.Result,
+				OriginalStatus:   pipelineCommit.OriginalStatus,
+				OriginalResult:   pipelineCommit.OriginalResult,
 				Status:           pipelineCommit.Status,
 				Environment:      pipelineCommit.Environment,
-				CreatedDate:      *pipelineCommit.CreatedDate,
-				FinishedDate:     pipelineCommit.FinishedDate,
-				DurationSec:      pipelineCommit.DurationSec,
-				CommitSha:        pipelineCommit.CommitSha,
-				RefName:          pipelineCommit.Branch,
-				RepoId:           pipelineCommit.RepoId,
-				RepoUrl:          pipelineCommit.RepoUrl,
+				TaskDatesInfo: devops.TaskDatesInfo{
+					CreatedDate:  *pipelineCommit.CreatedDate,
+					StartedDate:  pipelineCommit.StartedDate,
+					FinishedDate: pipelineCommit.FinishedDate,
+				},
+				DurationSec:       pipelineCommit.DurationSec,
+				QueuedDurationSec: pipelineCommit.QueuedDurationSec,
+				CommitSha:         pipelineCommit.CommitSha,
+				RefName:           pipelineCommit.Branch,
+				RepoId:            pipelineCommit.RepoId,
+				RepoUrl:           pipelineCommit.RepoUrl,
 			}
-			if pipelineCommit.FinishedDate != nil && pipelineCommit.DurationSec != nil {
-				s := pipelineCommit.FinishedDate.Add(-time.Duration(*pipelineCommit.DurationSec) * time.Second)
-				domainDeployCommit.StartedDate = &s
+			if domainDeployCommit.TaskDatesInfo.StartedDate == nil {
+				if pipelineCommit.FinishedDate != nil && pipelineCommit.DurationSec != nil {
+					s := pipelineCommit.FinishedDate.Add(-time.Duration(*pipelineCommit.DurationSec) * time.Second)
+					domainDeployCommit.StartedDate = &s
+				}
 			}
+
 			// it is tricky when Environment was declared on the cicd_tasks level
 			// lets talk common sense and assume that one pipeline can only be deployed to one environment
 			// so if the pipeline has both staging and production tasks, we will treat it as a production pipeline
@@ -156,6 +200,7 @@ func GenerateDeploymentCommits(taskCtx plugin.SubTaskContext) errors.Error {
 					domainDeployCommit.Environment = devops.TESTING
 				}
 			}
+			domainDeployCommit.SubtaskName = DORAGenerateDeploymentCommits
 			return []interface{}{domainDeployCommit}, nil
 		},
 	})
