@@ -19,7 +19,6 @@ package tasks
 
 import (
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
-	"github.com/apache/incubator-devlake/plugins/feishu/models"
 )
 
 type FeishuApiParams struct {
@@ -27,12 +26,12 @@ type FeishuApiParams struct {
 }
 
 type FeishuOptions struct {
-	ConnectionId       uint64  `json:"connectionId"`
-	NumOfDaysToCollect float64 `json:"numOfDaysToCollect"`
+	ConnectionId            uint64  `json:"connectionId"`
+	NumOfDaysToCollect      float64 `json:"numOfDaysToCollect"`
+	helper.CollectorOptions `mapstructure:",squash"`
 }
 
 type FeishuTaskData struct {
-	Options                  *FeishuOptions
-	ApiClient                *helper.ApiAsyncClient
-	FeishuMeetingTopUserItem *models.FeishuMeetingTopUserItem
+	Options   *FeishuOptions
+	ApiClient *helper.ApiAsyncClient
 }
