@@ -28,12 +28,18 @@ import (
 	"github.com/apache/incubator-devlake/plugins/github/models"
 )
 
+func init() {
+	RegisterSubtaskMeta(&ExtractJobsMeta)
+}
+
 var ExtractJobsMeta = plugin.SubTaskMeta{
 	Name:             "extractJobs",
 	EntryPoint:       ExtractJobs,
 	EnabledByDefault: true,
 	Description:      "Extract raw run data into tool layer table github_jobs",
 	DomainTypes:      []string{plugin.DOMAIN_TYPE_CICD},
+	DependencyTables: []string{RAW_JOB_TABLE},
+	ProductTables:    []string{models.GithubJob{}.TableName()},
 }
 
 func ExtractJobs(taskCtx plugin.SubTaskContext) errors.Error {
