@@ -20,7 +20,6 @@ package tasks
 import (
 	"fmt"
 	"strings"
-	"time"
 
 	"github.com/apache/incubator-devlake/core/errors"
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
@@ -28,21 +27,20 @@ import (
 )
 
 type GithubOptions struct {
-	ConnectionId  uint64                    `json:"connectionId" mapstructure:"connectionId,omitempty"`
-	ScopeConfigId uint64                    `json:"scopeConfigId" mapstructure:"scopeConfigId,omitempty"`
-	GithubId      int                       `json:"githubId" mapstructure:"githubId,omitempty"`
-	TimeAfter     string                    `json:"timeAfter" mapstructure:"timeAfter,omitempty"`
-	Owner         string                    `json:"owner" mapstructure:"owner,omitempty"`
-	Repo          string                    `json:"repo"  mapstructure:"repo,omitempty"`
-	Name          string                    `json:"name"  mapstructure:"name,omitempty"`
-	ScopeConfig   *models.GithubScopeConfig `mapstructure:"scopeConfig,omitempty" json:"scopeConfig"`
+	ConnectionId            uint64                    `json:"connectionId" mapstructure:"connectionId,omitempty"`
+	ScopeConfigId           uint64                    `json:"scopeConfigId" mapstructure:"scopeConfigId,omitempty"`
+	GithubId                int                       `json:"githubId" mapstructure:"githubId,omitempty"`
+	Owner                   string                    `json:"owner" mapstructure:"owner,omitempty"`
+	Repo                    string                    `json:"repo"  mapstructure:"repo,omitempty"`
+	Name                    string                    `json:"name"  mapstructure:"name,omitempty"`
+	ScopeConfig             *models.GithubScopeConfig `mapstructure:"scopeConfig,omitempty" json:"scopeConfig"`
+	helper.CollectorOptions `mapstructure:",squash"`
 }
 
 type GithubTaskData struct {
 	Options       *GithubOptions
 	ApiClient     *helper.ApiAsyncClient
 	GraphqlClient *helper.GraphqlAsyncClient
-	TimeAfter     *time.Time
 	RegexEnricher *helper.RegexEnricher
 }
 
@@ -70,15 +68,6 @@ func DecodeTaskOptions(options map[string]interface{}) (*GithubOptions, errors.E
 	return &op, nil
 }
 
-func EncodeTaskOptions(op *GithubOptions) (map[string]interface{}, errors.Error) {
-	var result map[string]interface{}
-	err := helper.Decode(op, &result, nil)
-	if err != nil {
-		return nil, err
-	}
-	return result, nil
-}
-
 func ValidateTaskOptions(op *GithubOptions) errors.Error {
 	if op.Name == "" {
 		op.Name = strings.Trim(fmt.Sprintf("%s/%s", op.Owner, op.Repo), " ")
