@@ -40,5 +40,11 @@ func All() []plugin.MigrationScript {
 		new(addMrCommitSha),
 		new(addRawParamTableForScope),
 		new(addProjectArchived),
+		new(addDeployment),
+		new(addEnvNamePattern),
+		new(addQueuedDuration20231129),
+		new(modifyDeploymentMessageType),
+		new(addTimeToGitlabPipelineProject),
+		new(modifyDeploymentCommitTitle),
 	}
 }
