@@ -141,19 +141,12 @@ func ExtractApiMergeRequests(taskCtx plugin.SubTaskContext) errors.Error {
 					ConnectionId: data.Options.ConnectionId,
 				})
 				// if pr.Type has not been set and prType is set in .env, process the below
-				if labelTypeRegex != nil {
-					groups := labelTypeRegex.FindStringSubmatch(label)
-					if len(groups) > 1 {
-						gitlabMergeRequest.Type = groups[1]
-					}
+				if labelTypeRegex != nil && labelTypeRegex.MatchString(label) {
+					gitlabMergeRequest.Type = label
 				}
-
 				// if pr.Component has not been set and prComponent is set in .env, process
-				if labelComponentRegex != nil {
-					groups := labelComponentRegex.FindStringSubmatch(label)
-					if len(groups) > 1 {
-						gitlabMergeRequest.Component = groups[1]
-					}
+				if labelComponentRegex != nil && labelComponentRegex.MatchString(label) {
+					gitlabMergeRequest.Component = label
 				}
 			}
 			for _, reviewer := range mr.Reviewers {
