@@ -33,5 +33,7 @@ func All() []plugin.MigrationScript {
 		new(addTransformationRule20221128),
 		new(addFullNameForBuilds),
 		new(addConnectionIdToTransformationRule),
+		new(renameTr2ScopeConfig),
+		new(addRawParamTableForScope),
 	}
 }
