@@ -22,6 +22,7 @@ import (
 	"encoding/base64"
 	"encoding/json"
 	"fmt"
+	"github.com/apache/incubator-devlake/core/models/common"
 	"net/http"
 	"net/url"
 	"strconv"
@@ -39,6 +40,7 @@ type RemoteScopesChild struct {
 	Id       string      `json:"id"`
 	Name     string      `json:"name"`
 	Data     interface{} `json:"data"`
+	FullName string      `json:"fullName"` // temporary fix, to adopt remote scope helper
 }
 
 type RemoteScopesOutput struct {
@@ -113,6 +115,11 @@ func RemoteScopes(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, er
 		return nil, err
 	}
 
+	search := input.Query.Get("search")
+	if search != "" {
+		query.Set("query", search)
+	}
+
 	var res *http.Response
 	outputBody := &RemoteScopesOutput{}
 	res, err = apiClient.Get("/services", query, nil)
@@ -127,13 +134,20 @@ func RemoteScopes(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, er
 	// append service to output
 	for _, service := range response.Services {
 		child := RemoteScopesChild{
-			Type: TypeScope,
-			Id:   service.Id,
-			Name: service.Name,
+			Type:     TypeScope,
+			Id:       service.Id,
+			Name:     service.Name,
+			FullName: service.Name,
 			Data: models.Service{
 				Url:  service.HtmlUrl,
 				Id:   service.Id,
 				Name: service.Name,
+				Scope: common.Scope{
+					NoPKModel: common.NoPKModel{
+						CreatedAt: service.CreatedAt,
+					},
+					ConnectionId: connection.ID,
+				},
 			},
 		}
 		outputBody.Children = append(outputBody.Children, child)
@@ -171,8 +185,7 @@ func RemoteScopes(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, er
 // @Failure 500  {object} shared.ApiBody "Internal Error"
 // @Router /plugins/pagerduty/connections/{connectionId}/search-remote-scopes [GET]
 func SearchRemoteScopes(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
-	// Not supported
-	return &plugin.ApiResourceOutput{Body: nil, Status: http.StatusMethodNotAllowed}, nil
+	return RemoteScopes(input)
 }
 
 func EncodeToPageToken(pageData *PageData) (string, errors.Error) {
