@@ -26,7 +26,9 @@ func All() []plugin.MigrationScript {
 		new(modifyCharacterSet),
 		new(expandProjectKey20230206),
 		new(addRawParamTableForScope),
+		new(addScopeConfigIdToProject),
 		new(modifyFileMetricsKeyLength),
 		new(modifyComponentLength),
+		new(addSonarQubeScopeConfig20231214),
 	}
 }
