@@ -19,9 +19,9 @@ package api
 
 import (
 	"strconv"
-	"time"
 
 	"github.com/apache/incubator-devlake/core/errors"
+	coreModels "github.com/apache/incubator-devlake/core/models"
 	"github.com/apache/incubator-devlake/core/models/domainlayer"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/didgen"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/ticket"
@@ -31,9 +31,13 @@ import (
 	"github.com/apache/incubator-devlake/plugins/tapd/models"
 )
 
-func MakeDataSourcePipelinePlanV200(subtaskMetas []plugin.SubTaskMeta, connectionId uint64, bpScopes []*plugin.BlueprintScopeV200, syncPolicy *plugin.BlueprintSyncPolicy) (plugin.PipelinePlan, []plugin.Scope, errors.Error) {
-	plan := make(plugin.PipelinePlan, len(bpScopes))
-	plan, err := makeDataSourcePipelinePlanV200(subtaskMetas, plan, bpScopes, connectionId, syncPolicy)
+func MakeDataSourcePipelinePlanV200(
+	subtaskMetas []plugin.SubTaskMeta,
+	connectionId uint64,
+	bpScopes []*coreModels.BlueprintScope,
+) (coreModels.PipelinePlan, []plugin.Scope, errors.Error) {
+	plan := make(coreModels.PipelinePlan, len(bpScopes))
+	plan, err := makeDataSourcePipelinePlanV200(subtaskMetas, plan, bpScopes, connectionId)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -47,29 +51,25 @@ func MakeDataSourcePipelinePlanV200(subtaskMetas []plugin.SubTaskMeta, connectio
 
 func makeDataSourcePipelinePlanV200(
 	subtaskMetas []plugin.SubTaskMeta,
-	plan plugin.PipelinePlan,
-	bpScopes []*plugin.BlueprintScopeV200,
+	plan coreModels.PipelinePlan,
+	bpScopes []*coreModels.BlueprintScope,
 	connectionId uint64,
-	syncPolicy *plugin.BlueprintSyncPolicy,
-) (plugin.PipelinePlan, errors.Error) {
+) (coreModels.PipelinePlan, errors.Error) {
 	for i, bpScope := range bpScopes {
 		stage := plan[i]
 		if stage == nil {
-			stage = plugin.PipelineStage{}
+			stage = coreModels.PipelineStage{}
 		}
 		// construct task options for tapd
 		options := make(map[string]interface{})
-		intNum, err := errors.Convert01(strconv.Atoi(bpScope.Id))
+		intNum, err := errors.Convert01(strconv.Atoi(bpScope.ScopeId))
 		if err != nil {
 			return nil, err
 		}
 		options["workspaceId"] = intNum
 		options["connectionId"] = connectionId
-		if syncPolicy.TimeAfter != nil {
-			options["timeAfter"] = syncPolicy.TimeAfter.Format(time.RFC3339)
-		}
 
-		_, scopeConfig, err := scopeHelper.DbHelper().GetScopeAndConfig(connectionId, bpScope.Id)
+		_, scopeConfig, err := scopeHelper.DbHelper().GetScopeAndConfig(connectionId, bpScope.ScopeId)
 		if err != nil {
 			return nil, err
 		}
@@ -78,7 +78,7 @@ func makeDataSourcePipelinePlanV200(
 		if err != nil {
 			return nil, err
 		}
-		stage = append(stage, &plugin.PipelineTask{
+		stage = append(stage, &coreModels.PipelineTask{
 			Plugin:   "tapd",
 			Subtasks: subtasks,
 			Options:  options,
@@ -90,14 +90,14 @@ func makeDataSourcePipelinePlanV200(
 }
 
 func makeScopesV200(
-	bpScopes []*plugin.BlueprintScopeV200,
+	bpScopes []*coreModels.BlueprintScope,
 	connectionId uint64) ([]plugin.Scope, errors.Error,
 ) {
 	scopes := make([]plugin.Scope, 0)
 	for _, bpScope := range bpScopes {
 		// get workspace and scope config from db
 
-		tapdWorkspace, scopeConfig, err := scopeHelper.DbHelper().GetScopeAndConfig(connectionId, bpScope.Id)
+		tapdWorkspace, scopeConfig, err := scopeHelper.DbHelper().GetScopeAndConfig(connectionId, bpScope.ScopeId)
 		if err != nil {
 			return nil, err
 		}
