@@ -20,14 +20,15 @@ package tasks
 import (
 	"encoding/json"
 	"fmt"
+	"net/http"
+	"net/url"
+	"reflect"
+
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 	"github.com/apache/incubator-devlake/plugins/tapd/models"
-	"net/http"
-	"net/url"
-	"reflect"
 )
 
 const RAW_BUG_COMMIT_TABLE = "tapd_api_bug_commits"
@@ -37,23 +38,20 @@ var _ plugin.SubTaskEntryPoint = CollectBugCommits
 func CollectBugCommits(taskCtx plugin.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_BUG_COMMIT_TABLE)
 	db := taskCtx.GetDal()
-	collectorWithState, err := api.NewStatefulApiCollector(*rawDataSubTaskArgs, data.TimeAfter)
+	collectorWithState, err := api.NewStatefulApiCollector(*rawDataSubTaskArgs)
 	if err != nil {
 		return err
 	}
 	logger := taskCtx.GetLogger()
 	logger.Info("collect issueCommits")
-	incremental := collectorWithState.IsIncremental()
+
 	clauses := []dal.Clause{
 		dal.Select("_tool_tapd_bugs.id as issue_id, modified as update_time"),
 		dal.From(&models.TapdBug{}),
 		dal.Where("_tool_tapd_bugs.connection_id = ? and _tool_tapd_bugs.workspace_id = ? ", data.Options.ConnectionId, data.Options.WorkspaceId),
 	}
-	if collectorWithState.TimeAfter != nil {
-		clauses = append(clauses, dal.Where("modified > ?", *collectorWithState.TimeAfter))
-	}
-	if incremental {
-		clauses = append(clauses, dal.Where("modified > ?", *collectorWithState.LatestState.LatestSuccessStart))
+	if collectorWithState.Since != nil {
+		clauses = append(clauses, dal.Where("modified > ?", *collectorWithState.Since))
 	}
 	cursor, err := db.Cursor(clauses...)
 	if err != nil {
@@ -66,7 +64,6 @@ func CollectBugCommits(taskCtx plugin.SubTaskContext) errors.Error {
 	}
 	err = collectorWithState.InitCollector(api.ApiCollectorArgs{
 		ApiClient:   data.ApiClient,
-		Incremental: incremental,
 		Input:       iterator,
 		UrlTemplate: "code_commit_infos",
 		Query: func(reqData *api.RequestData) (url.Values, errors.Error) {
