@@ -34,14 +34,12 @@ func CollectWorklogs(taskCtx plugin.SubTaskContext) errors.Error {
 	rawDataSubTaskArgs, data := CreateRawDataSubTaskArgs(taskCtx, RAW_WORKLOG_TABLE)
 	logger := taskCtx.GetLogger()
 	logger.Info("collect worklogs")
-	collectorWithState, err := helper.NewStatefulApiCollector(*rawDataSubTaskArgs, data.TimeAfter)
+	collectorWithState, err := helper.NewStatefulApiCollector(*rawDataSubTaskArgs)
 	if err != nil {
 		return err
 	}
-	incremental := collectorWithState.IsIncremental()
 
 	err = collectorWithState.InitCollector(helper.ApiCollectorArgs{
-		Incremental: incremental,
 		ApiClient:   data.ApiClient,
 		PageSize:    int(data.Options.PageSize),
 		UrlTemplate: "timesheets",
@@ -51,15 +49,8 @@ func CollectWorklogs(taskCtx plugin.SubTaskContext) errors.Error {
 			query.Set("page", fmt.Sprintf("%v", reqData.Pager.Page))
 			query.Set("limit", fmt.Sprintf("%v", reqData.Pager.Size))
 			query.Set("order", "created asc")
-			if data.TimeAfter != nil {
-				query.Set("modified",
-					fmt.Sprintf(">%s",
-						data.TimeAfter.In(data.Options.CstZone).Format("2006-01-02")))
-			}
-			if incremental {
-				query.Set("modified",
-					fmt.Sprintf(">%s",
-						collectorWithState.LatestState.LatestSuccessStart.In(data.Options.CstZone).Format("2006-01-02")))
+			if collectorWithState.Since != nil {
+				query.Set("modified", fmt.Sprintf(">%s", collectorWithState.Since.In(data.Options.CstZone).Format("2006-01-02")))
 			}
 			return query, nil
 		},
