@@ -19,20 +19,22 @@ package api
 
 import (
 	"fmt"
-	"github.com/apache/incubator-devlake/core/dal"
-	"github.com/apache/incubator-devlake/core/errors"
-	"github.com/apache/incubator-devlake/core/plugin"
-	"github.com/apache/incubator-devlake/plugins/webhook/models"
 	"net/http"
 	"strconv"
+
+	"github.com/apache/incubator-devlake/core/dal"
+	"github.com/apache/incubator-devlake/core/errors"
+	coreModels "github.com/apache/incubator-devlake/core/models"
+	"github.com/apache/incubator-devlake/core/plugin"
+	"github.com/apache/incubator-devlake/plugins/webhook/models"
 )
 
 // PostConnections
 // @Summary create webhook connection
 // @Description Create webhook connection, example: {"name":"Webhook data connection name"}
 // @Tags plugins/webhook
-// @Param body body models.WebhookConnection true "json body"
-// @Success 200  {object} models.WebhookConnection
+// @Param body body WebhookConnectionResponse true "json body"
+// @Success 200  {object} WebhookConnectionResponse
 // @Failure 400  {string} errcode.Error "Bad Request"
 // @Failure 500  {string} errcode.Error "Internal Error"
 // @Router /plugins/webhook/connections [POST]
@@ -45,7 +47,7 @@ func PostConnections(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput,
 		return nil, err
 	}
 	logger.Info("connection: %+v", connection)
-	name := fmt.Sprintf("%s-%d", pluginName, connection.ID)
+	name := apiKeyHelper.GenApiKeyNameForPlugin(pluginName, connection.ID)
 	allowedPath := fmt.Sprintf("/plugins/%s/connections/%d/.*", pluginName, connection.ID)
 	extra := fmt.Sprintf("connectionId:%d", connection.ID)
 	apiKeyRecord, err := apiKeyHelper.CreateForPlugin(tx, input.User, name, pluginName, allowedPath, extra)
@@ -60,13 +62,14 @@ func PostConnections(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput,
 		logger.Info("transaction commit: %s", err)
 	}
 
-	apiOutputConnection := models.ApiOutputWebhookConnection{
-		WebhookConnection: *connection,
-		ApiKey:            apiKeyRecord,
+	webhookConnectionResponse, err := formatConnection(connection, false)
+	if err != nil {
+		return nil, err
 	}
-	logger.Info("api output connection: %+v", apiOutputConnection)
+	webhookConnectionResponse.ApiKey = apiKeyRecord
+	logger.Info("api output connection: %+v", webhookConnectionResponse)
 
-	return &plugin.ApiResourceOutput{Body: apiOutputConnection, Status: http.StatusOK}, nil
+	return &plugin.ApiResourceOutput{Body: webhookConnectionResponse, Status: http.StatusOK}, nil
 }
 
 // PatchConnection
@@ -129,11 +132,12 @@ func DeleteConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput
 
 type WebhookConnectionResponse struct {
 	models.WebhookConnection
-	PostIssuesEndpoint             string `json:"postIssuesEndpoint"`
-	CloseIssuesEndpoint            string `json:"closeIssuesEndpoint"`
-	PostPipelineTaskEndpoint       string `json:"postPipelineTaskEndpoint"`
-	PostPipelineDeployTaskEndpoint string `json:"postPipelineDeployTaskEndpoint"`
-	ClosePipelineEndpoint          string `json:"closePipelineEndpoint"`
+	PostIssuesEndpoint             string             `json:"postIssuesEndpoint"`
+	CloseIssuesEndpoint            string             `json:"closeIssuesEndpoint"`
+	PostPipelineTaskEndpoint       string             `json:"postPipelineTaskEndpoint"`
+	PostPipelineDeployTaskEndpoint string             `json:"postPipelineDeployTaskEndpoint"`
+	ClosePipelineEndpoint          string             `json:"closePipelineEndpoint"`
+	ApiKey                         *coreModels.ApiKey `json:"apiKey,omitempty"`
 }
 
 // ListConnections
@@ -150,9 +154,13 @@ func ListConnections(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput,
 	if err != nil {
 		return nil, err
 	}
-	responseList := []WebhookConnectionResponse{}
+	responseList := []*WebhookConnectionResponse{}
 	for _, connection := range connections {
-		responseList = append(responseList, *formatConnection(&connection))
+		webhookConnectionResponse, err := formatConnection(&connection, true)
+		if err != nil {
+			return nil, err
+		}
+		responseList = append(responseList, webhookConnectionResponse)
 	}
 	return &plugin.ApiResourceOutput{Body: responseList, Status: http.StatusOK}, nil
 }
@@ -168,16 +176,36 @@ func ListConnections(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput,
 func GetConnection(input *plugin.ApiResourceInput) (*plugin.ApiResourceOutput, errors.Error) {
 	connection := &models.WebhookConnection{}
 	err := connectionHelper.First(connection, input.Params)
-	response := formatConnection(connection)
+	if err != nil {
+		logger.Error(err, "query connection")
+		return nil, err
+	}
+	response, err := formatConnection(connection, true)
 	return &plugin.ApiResourceOutput{Body: response}, err
 }
 
-func formatConnection(connection *models.WebhookConnection) *WebhookConnectionResponse {
+func formatConnection(connection *models.WebhookConnection, withApiKeyInfo bool) (*WebhookConnectionResponse, errors.Error) {
 	response := &WebhookConnectionResponse{WebhookConnection: *connection}
-	response.PostIssuesEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/issues`, connection.ID)
-	response.CloseIssuesEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/issue/:issueKey/close`, connection.ID)
-	response.PostPipelineTaskEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/cicd_tasks`, connection.ID)
-	response.PostPipelineDeployTaskEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/deployments`, connection.ID)
-	response.ClosePipelineEndpoint = fmt.Sprintf(`/plugins/webhook/connections/%d/cicd_pipeline/:pipelineName/finish`, connection.ID)
-	return response
+	response.PostIssuesEndpoint = fmt.Sprintf(`/rest/plugins/webhook/connections/%d/issues`, connection.ID)
+	response.CloseIssuesEndpoint = fmt.Sprintf(`/rest/plugins/webhook/connections/%d/issue/:issueKey/close`, connection.ID)
+	response.PostPipelineTaskEndpoint = fmt.Sprintf(`/rest/plugins/webhook/connections/%d/cicd_tasks`, connection.ID)
+	response.PostPipelineDeployTaskEndpoint = fmt.Sprintf(`/rest/plugins/webhook/connections/%d/deployments`, connection.ID)
+	response.ClosePipelineEndpoint = fmt.Sprintf(`/rest/plugins/webhook/connections/%d/cicd_pipeline/:pipelineName/finish`, connection.ID)
+	if withApiKeyInfo {
+		db := basicRes.GetDal()
+		apiKeyName := apiKeyHelper.GenApiKeyNameForPlugin(pluginName, connection.ID)
+		apiKey, err := apiKeyHelper.GetApiKey(db, dal.Where("name = ?", apiKeyName))
+		if err != nil {
+			if db.IsErrorNotFound(err) {
+				logger.Info("api key with name: %s not found in db", apiKeyName)
+			} else {
+				logger.Error(err, "query api key from db, name: %s", apiKeyName)
+				return nil, err
+			}
+		} else {
+			response.ApiKey = apiKey
+			response.ApiKey.RemoveHashedApiKey() // delete the hashed api key to reduce the attack surface.
+		}
+	}
+	return response, nil
 }
