@@ -21,6 +21,7 @@ import (
 	"github.com/apache/incubator-devlake/core/context"
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
+	coreModels "github.com/apache/incubator-devlake/core/models"
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/plugins/webhook/api"
 	"github.com/apache/incubator-devlake/plugins/webhook/models"
@@ -34,6 +35,7 @@ var _ interface {
 	plugin.PluginApi
 	plugin.PluginModel
 	plugin.PluginMigration
+	plugin.DataSourcePluginBlueprintV200
 } = (*Webhook)(nil)
 
 type Webhook struct{}
@@ -58,11 +60,14 @@ func (p Webhook) GetTablesInfo() []dal.Tabler {
 	}
 }
 
-func (p Webhook) MakeDataSourcePipelinePlanV200(connectionId uint64, _ []*plugin.BlueprintScopeV200, _ plugin.BlueprintSyncPolicy) (pp plugin.PipelinePlan, sc []plugin.Scope, err errors.Error) {
+func (p Webhook) MakeDataSourcePipelinePlanV200(
+	connectionId uint64,
+	_ []*coreModels.BlueprintScope,
+) (pp coreModels.PipelinePlan, sc []plugin.Scope, err errors.Error) {
 	return api.MakeDataSourcePipelinePlanV200(connectionId)
 }
 
-// PkgPath information lost when compiled as plugin(.so)
+// RootPkgPath information lost when compiled as plugin(.so)
 func (p Webhook) RootPkgPath() string {
 	return "github.com/apache/incubator-devlake/plugins/webhook"
 }
