@@ -29,7 +29,6 @@ from sqlalchemy.inspection import inspect
 from sqlmodel import SQLModel
 from pydevlake import Field
 
-
 inflect_engine = inflect.engine()
 
 
@@ -42,6 +41,10 @@ class Model(SQLModel):
         sa_column=Column(DateTime(), default=datetime.utcnow, onupdate=datetime.utcnow)
     )
 
+    def set_updated_at(self):
+        if self.updated_at is None:
+            self.updated_at = datetime.utcnow()
+
 
 class ToolTable(SQLModel):
     @declared_attr
@@ -132,6 +135,10 @@ class NoPKModel(RawDataOrigin):
         sa_column=Column(DateTime(), default=datetime.utcnow, onupdate=datetime.utcnow)
     )
 
+    def set_updated_at(self):
+        if self.updated_at is None:
+            self.updated_at = datetime.utcnow()
+
 
 class ToolModel(ToolTable, NoPKModel):
     connection_id: Optional[int] = Field(primary_key=True, auto_increment=False)
