@@ -32,7 +32,7 @@ import (
 	ginSwagger "github.com/swaggo/gin-swagger"
 	"github.com/swaggo/swag"
 
-	"github.com/apache/incubator-devlake/core/config"
+	"github.com/apache/incubator-devlake/core/context"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/impls/logruslog"
@@ -50,32 +50,47 @@ To proceed, please send a request to <config-ui-endpoint>/api/proceed-db-migrati
 Alternatively, you may downgrade back to the previous DevLake version.
 `
 
+var basicRes context.BasicRes
+
+func Init() {
+	// Initialize services
+	services.Init()
+	basicRes = services.GetBasicRes()
+}
+
 // @title  DevLake Swagger API
 // @version 0.1
 // @description  <h2>This is the main page of devlake api</h2>
 // @license.name Apache-2.0
 // @host localhost:8080
 // @BasePath /
-func CreateApiService() {
-	// Get configuration
-	v := config.GetConfig()
-	// Initialize services
-	services.Init()
-	// Set gin mode
-	gin.SetMode(v.GetString("MODE"))
-	// Create a gin router
+func CreateAndRunApiServer() {
+	// Setup and run the server
+	Init()
+	router := CreateApiServer()
+	SetupApiServer(router)
+	RunApiServer(router)
+}
+
+func CreateApiServer() *gin.Engine {
+	// Create router
 	router := gin.Default()
 
 	// For both protected and unprotected routes
 	router.GET("/ping", ping.Get)
+	router.GET("/health", ping.Get)
 	router.GET("/version", version.Get)
-	router.GET("/userinfo", func(ctx *gin.Context) {
-		shared.ApiOutputSuccess(ctx, gin.H{
-			"user":      ctx.Request.Header.Get("X-Forwarded-User"),
-			"email":     ctx.Request.Header.Get("X-Forwarded-Email"),
-			"logoutURI": config.GetConfig().GetString("LOGOUT_URI"),
-		}, http.StatusOK)
-	})
+
+	// Api keys
+	router.Use(RestAuthentication(router, basicRes))
+	router.Use(OAuth2ProxyAuthentication(basicRes))
+
+	return router
+}
+
+func SetupApiServer(router *gin.Engine) {
+	// Set gin mode
+	gin.SetMode(basicRes.GetConfig("MODE"))
 
 	// Endpoint to proceed database migration
 	router.GET("/proceed-db-migration", func(ctx *gin.Context) {
@@ -96,11 +111,6 @@ func CreateApiService() {
 		shared.ApiOutputSuccess(ctx, nil, http.StatusOK)
 	})
 
-	// Api keys
-	basicRes := services.GetBasicRes()
-	router.Use(RestAuthentication(router, basicRes))
-	router.Use(OAuth2ProxyAuthentication(basicRes))
-
 	// Restrict access if database migration is required
 	router.Use(func(ctx *gin.Context) {
 		if !services.MigrationRequireConfirmation() {
@@ -141,8 +151,11 @@ func CreateApiService() {
 
 	// Register API endpoints
 	RegisterRouter(router, basicRes)
+}
+
+func RunApiServer(router *gin.Engine) {
 	// Get port from config
-	port := v.GetString("PORT")
+	port := basicRes.GetConfig("PORT")
 	// Trim any : from the start
 	port = strings.TrimLeft(port, ":")
 	// Convert to int
@@ -153,7 +166,7 @@ func CreateApiService() {
 	}
 
 	// Start the server
-	err = router.Run(fmt.Sprintf("0.0.0.0:%d", portNum))
+	err = router.Run(fmt.Sprintf(":%d", portNum))
 	if err != nil {
 		panic(err)
 	}
