@@ -77,7 +77,7 @@ func RegisterRouter(r *gin.Engine, basicRes context.BasicRes) {
 	// api keys api
 	r.GET("/api-keys", apikeys.GetApiKeys)
 	r.POST("/api-keys", apikeys.PostApiKey)
-	r.PUT("/api-keys/:apiKeyId/", apikeys.PutApiKey)
+	r.PUT("/api-keys/:apiKeyId", apikeys.PutApiKey)
 	r.DELETE("/api-keys/:apiKeyId", apikeys.DeleteApiKey)
 
 	// mount all api resources for all plugins
@@ -145,6 +145,13 @@ func handlePluginCall(basicRes context.BasicRes, pluginName string, handler plug
 			if status < http.StatusContinue {
 				status = http.StatusOK
 			}
+			if output.Header != nil {
+				for k, vs := range output.Header {
+					for _, v := range vs {
+						c.Header(k, v)
+					}
+				}
+			}
 			if output.File != nil {
 				c.Data(status, output.File.ContentType, output.File.Data)
 				return
