@@ -28,7 +28,6 @@ import (
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/models"
-	"github.com/apache/incubator-devlake/core/plugin"
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 	"github.com/apache/incubator-devlake/impls/logruslog"
 	"github.com/robfig/cron/v3"
@@ -55,7 +54,7 @@ type BlueprintJob struct {
 
 func (bj BlueprintJob) Run() {
 	blueprint := bj.Blueprint
-	pipeline, err := createPipelineByBlueprint(blueprint, false)
+	pipeline, err := createPipelineByBlueprint(blueprint, &blueprint.SyncPolicy)
 	if err == ErrEmptyPlan {
 		blueprintLog.Info("Empty plan, blueprint id:[%d] blueprint name:[%s]", blueprint.ID, blueprint.Name)
 		return
@@ -69,24 +68,13 @@ func (bj BlueprintJob) Run() {
 
 // CreateBlueprint accepts a Blueprint instance and insert it to database
 func CreateBlueprint(blueprint *models.Blueprint) errors.Error {
-	err := validateBlueprintAndMakePlan(blueprint)
-	if err != nil {
-		return err
-	}
-	err = bpManager.SaveDbBlueprint(blueprint)
-	if err != nil {
-		return err
-	}
-	err = ReloadBlueprints(cronManager)
-	if err != nil {
-		return errors.Internal.Wrap(err, "error reloading blueprints")
-	}
-	return nil
+	_, err := saveBlueprint(blueprint)
+	return err
 }
 
 // GetBlueprints returns a paginated list of Blueprints based on `query`
-func GetBlueprints(query *BlueprintQuery) ([]*models.Blueprint, int64, errors.Error) {
-	return bpManager.GetDbBlueprints(&services.GetBlueprintQuery{
+func GetBlueprints(query *BlueprintQuery, shouldSanitize bool) ([]*models.Blueprint, int64, errors.Error) {
+	blueprints, count, err := bpManager.GetDbBlueprints(&services.GetBlueprintQuery{
 		Enable:      query.Enable,
 		IsManual:    query.IsManual,
 		Label:       query.Label,
@@ -94,10 +82,23 @@ func GetBlueprints(query *BlueprintQuery) ([]*models.Blueprint, int64, errors.Er
 		PageSize:    query.GetPageSize(),
 		Type:        query.Type,
 	})
+	if err != nil {
+		return nil, 0, err
+	}
+	if shouldSanitize {
+		for idx, bp := range blueprints {
+			if err := SanitizeBlueprint(bp); err != nil {
+				return nil, 0, errors.Convert(err)
+			} else {
+				blueprints[idx] = bp
+			}
+		}
+	}
+	return blueprints, count, nil
 }
 
 // GetBlueprint returns the detail of a given Blueprint ID
-func GetBlueprint(blueprintId uint64) (*models.Blueprint, errors.Error) {
+func GetBlueprint(blueprintId uint64, shouldSanitize bool) (*models.Blueprint, errors.Error) {
 	blueprint, err := bpManager.GetDbBlueprint(blueprintId)
 	if err != nil {
 		if db.IsErrorNotFound(err) {
@@ -105,6 +106,11 @@ func GetBlueprint(blueprintId uint64) (*models.Blueprint, errors.Error) {
 		}
 		return nil, errors.Internal.Wrap(err, "error getting the blueprint from database")
 	}
+	if shouldSanitize {
+		if err := SanitizeBlueprint(blueprint); err != nil {
+			return nil, errors.Convert(err)
+		}
+	}
 	return blueprint, nil
 }
 
@@ -125,9 +131,6 @@ func GetBlueprintByProjectName(projectName string) (*models.Blueprint, errors.Er
 }
 
 func validateBlueprintAndMakePlan(blueprint *models.Blueprint) errors.Error {
-	if len(blueprint.Settings) == 0 {
-		blueprint.Settings = nil
-	}
 	// validation
 	err := vld.Struct(blueprint)
 	if err != nil {
@@ -167,8 +170,8 @@ func validateBlueprintAndMakePlan(blueprint *models.Blueprint) errors.Error {
 		}
 	} else if blueprint.Mode == models.BLUEPRINT_MODE_NORMAL {
 		var e errors.Error
-		blueprint.Plan, e = MakePlanForBlueprint(blueprint, false)
-		if err != nil {
+		blueprint.Plan, e = MakePlanForBlueprint(blueprint, &blueprint.SyncPolicy)
+		if e != nil {
 			return e
 		}
 	}
@@ -187,9 +190,9 @@ func saveBlueprint(blueprint *models.Blueprint) (*models.Blueprint, errors.Error
 	}
 
 	// reload schedule
-	err = ReloadBlueprints(cronManager)
+	err = reloadBlueprint(blueprint)
 	if err != nil {
-		return nil, errors.Internal.Wrap(err, "error reloading blueprints")
+		return nil, err
 	}
 	// done
 	return blueprint, nil
@@ -198,7 +201,7 @@ func saveBlueprint(blueprint *models.Blueprint) (*models.Blueprint, errors.Error
 // PatchBlueprint FIXME ...
 func PatchBlueprint(id uint64, body map[string]interface{}) (*models.Blueprint, errors.Error) {
 	// load record from db
-	blueprint, err := GetBlueprint(id)
+	blueprint, err := GetBlueprint(id, false)
 	if err != nil {
 		return nil, err
 	}
@@ -208,16 +211,24 @@ func PatchBlueprint(id uint64, body map[string]interface{}) (*models.Blueprint,
 	if err != nil {
 		return nil, err
 	}
+
 	// make sure mode is not being updated
 	if originMode != blueprint.Mode {
 		return nil, errors.Default.New("mode is not updatable")
 	}
+	// syncPolicy can be updated, so we need to decode it again
+	err = helper.DecodeMapStruct(body, &blueprint.SyncPolicy, true)
+	if err != nil {
+		return nil, err
+	}
 
 	blueprint, err = saveBlueprint(blueprint)
 	if err != nil {
 		return nil, err
 	}
-
+	if err := SanitizeBlueprint(blueprint); err != nil {
+		return nil, errors.Convert(err)
+	}
 	return blueprint, nil
 }
 
@@ -235,14 +246,10 @@ func DeleteBlueprint(id uint64) errors.Error {
 }
 
 var blueprintReloadLock sync.Mutex
+var bpCronIdMap map[uint64]cron.EntryID
 
-// ReloadBlueprints FIXME ...
-func ReloadBlueprints(c *cron.Cron) (err errors.Error) {
-	// preventing concurrent reloads. It would be better to use Table Lock , however, it requires massive refactor
-	// like the `bpManager` must accept transaction. Use mutex as a temporary fix.
-	blueprintReloadLock.Lock()
-	defer blueprintReloadLock.Unlock()
-
+// ReloadBlueprints reloades cronjobs based on blueprints
+func ReloadBlueprints() (err errors.Error) {
 	enable := true
 	isManual := false
 	blueprints, _, err := bpManager.GetDbBlueprints(&services.GetBlueprintQuery{
@@ -252,32 +259,51 @@ func ReloadBlueprints(c *cron.Cron) (err errors.Error) {
 	if err != nil {
 		return err
 	}
-	for _, e := range c.Entries() {
-		c.Remove(e.ID)
+	for _, e := range cronManager.Entries() {
+		cronManager.Remove(e.ID)
 	}
-	c.Stop()
+	cronManager.Stop()
+	bpCronIdMap = make(map[uint64]cron.EntryID, len(blueprints))
 	for _, blueprint := range blueprints {
-		blueprintLog.Info("Add blueprint id:[%d] cronConfg[%s] to cron job", blueprint.ID, blueprint.CronConfig)
-		blueprintJob := &BlueprintJob{
-			Blueprint: blueprint,
-		}
-		if _, err := c.AddJob(blueprint.CronConfig, blueprintJob); err != nil {
-			blueprintLog.Error(err, failToCreateCronJob)
-			return errors.Default.Wrap(err, "created cron job failed")
+		err := reloadBlueprint(blueprint)
+		if err != nil {
+			return err
 		}
 	}
-	if len(blueprints) > 0 {
-		c.Start()
-	}
+	cronManager.Start()
 	logger.Info("total %d blueprints were scheduled", len(blueprints))
 	return nil
 }
 
-func createPipelineByBlueprint(blueprint *models.Blueprint, skipCollectors bool) (*models.Pipeline, errors.Error) {
-	var plan plugin.PipelinePlan
+func reloadBlueprint(blueprint *models.Blueprint) errors.Error {
+	// preventing concurrent reloads. It would be better to use Table Lock , however, it requires massive refactor
+	// like the `bpManager` must accept transaction. Use mutex as a temporary fix.
+	blueprintReloadLock.Lock()
+	defer blueprintReloadLock.Unlock()
+
+	cronId, scheduled := bpCronIdMap[blueprint.ID]
+	if scheduled {
+		cronManager.Remove(cronId)
+		delete(bpCronIdMap, blueprint.ID)
+		logger.Info("removed blueprint %d from cronjobs, cron id: %v", blueprint.ID, cronId)
+	}
+	if blueprint.Enable && !blueprint.IsManual {
+		if cronId, err := cronManager.AddJob(blueprint.CronConfig, &BlueprintJob{blueprint}); err != nil {
+			blueprintLog.Error(err, failToCreateCronJob)
+			return errors.Default.Wrap(err, "created cron job failed")
+		} else {
+			bpCronIdMap[blueprint.ID] = cronId
+			logger.Info("added blueprint %d to cronjobs, cron id: %v, cron config: %s", blueprint.ID, cronId, blueprint.CronConfig)
+		}
+	}
+	return nil
+}
+
+func createPipelineByBlueprint(blueprint *models.Blueprint, syncPolicy *models.SyncPolicy) (*models.Pipeline, errors.Error) {
+	var plan models.PipelinePlan
 	var err errors.Error
 	if blueprint.Mode == models.BLUEPRINT_MODE_NORMAL {
-		plan, err = MakePlanForBlueprint(blueprint, skipCollectors)
+		plan, err = MakePlanForBlueprint(blueprint, syncPolicy)
 		if err != nil {
 			blueprintLog.Error(err, fmt.Sprintf("failed to MakePlanForBlueprint on blueprint:[%d][%s]", blueprint.ID, blueprint.Name))
 			return nil, err
@@ -285,30 +311,31 @@ func createPipelineByBlueprint(blueprint *models.Blueprint, skipCollectors bool)
 	} else {
 		plan = blueprint.Plan
 	}
+
 	newPipeline := models.NewPipeline{}
 	newPipeline.Plan = plan
 	newPipeline.Name = blueprint.Name
 	newPipeline.BlueprintId = blueprint.ID
 	newPipeline.Labels = blueprint.Labels
-	newPipeline.SkipOnFail = blueprint.SkipOnFail
+	newPipeline.SyncPolicy = blueprint.SyncPolicy
 
 	// if the plan is empty, we should not create the pipeline
-	var shouldCreatePipeline bool
-	for _, stage := range plan {
-		for _, task := range stage {
-			switch task.Plugin {
-			case "org", "refdiff", "dora":
-			default:
-				if !plan.IsEmpty() {
-					shouldCreatePipeline = true
-				}
-			}
-		}
-	}
-	if !shouldCreatePipeline {
-		return nil, ErrEmptyPlan
-	}
-	pipeline, err := CreatePipeline(&newPipeline)
+	// var shouldCreatePipeline bool
+	// for _, stage := range plan {
+	// 	for _, task := range stage {
+	// 		switch task.Plugin {
+	// 		case "org", "refdiff", "dora":
+	// 		default:
+	// 			if !plan.IsEmpty() {
+	// 				shouldCreatePipeline = true
+	// 			}
+	// 		}
+	// 	}
+	// }
+	// if !shouldCreatePipeline {
+	// 	return nil, ErrEmptyPlan
+	// }
+	pipeline, err := CreatePipeline(&newPipeline, false)
 	// Return all created tasks to the User
 	if err != nil {
 		blueprintLog.Error(err, fmt.Sprintf("%s on blueprint:[%d][%s]", failToCreateCronJob, blueprint.ID, blueprint.Name))
@@ -318,68 +345,35 @@ func createPipelineByBlueprint(blueprint *models.Blueprint, skipCollectors bool)
 }
 
 // MakePlanForBlueprint generates pipeline plan by version
-func MakePlanForBlueprint(blueprint *models.Blueprint, skipCollectors bool) (plugin.PipelinePlan, errors.Error) {
-	bpSettings := new(models.BlueprintSettings)
-	err := errors.Convert(json.Unmarshal(blueprint.Settings, bpSettings))
-	if err != nil {
-		return nil, errors.Default.Wrap(err, fmt.Sprintf("settings:%s", string(blueprint.Settings)))
-	}
-
-	bpSyncPolicy := plugin.BlueprintSyncPolicy{}
-	bpSyncPolicy.TimeAfter = bpSettings.TimeAfter
-
-	var plan plugin.PipelinePlan
-	switch bpSettings.Version {
-	case "1.0.0":
-		return nil, errors.BadInput.New("Blueprint v1.0.0 had been deprecated, please se v2.0.0 instead")
-	case "2.0.0":
-		// load project metric plugins and convert it to a map
-		metrics := make(map[string]json.RawMessage)
-		projectMetrics := make([]models.ProjectMetricSetting, 0)
-		if blueprint.ProjectName != "" {
-			err = db.All(&projectMetrics, dal.Where("project_name = ? AND enable = ?", blueprint.ProjectName, true))
-			if err != nil {
-				return nil, err
-			}
-			for _, projectMetric := range projectMetrics {
-				metrics[projectMetric.PluginName] = json.RawMessage(projectMetric.PluginOption)
-			}
+func MakePlanForBlueprint(blueprint *models.Blueprint, syncPolicy *models.SyncPolicy) (models.PipelinePlan, errors.Error) {
+	var plan models.PipelinePlan
+	// load project metric plugins and convert it to a map
+	metrics := make(map[string]json.RawMessage)
+	projectMetrics := make([]models.ProjectMetricSetting, 0)
+	if blueprint.ProjectName != "" {
+		err := db.All(&projectMetrics, dal.Where("project_name = ? AND enable = ?", blueprint.ProjectName, true))
+		if err != nil {
+			return nil, err
+		}
+		for _, projectMetric := range projectMetrics {
+			metrics[projectMetric.PluginName] = json.RawMessage(projectMetric.PluginOption)
 		}
-		plan, err = GeneratePlanJsonV200(blueprint.ProjectName, bpSyncPolicy, bpSettings, metrics, skipCollectors)
-	default:
-		return nil, errors.Default.New(fmt.Sprintf("unknown version of blueprint settings: %s", bpSettings.Version))
 	}
+	skipCollectors := false
+	if syncPolicy != nil && syncPolicy.SkipCollectors {
+		skipCollectors = true
+	}
+	plan, err := GeneratePlanJsonV200(blueprint.ProjectName, blueprint.Connections, metrics, skipCollectors)
 	if err != nil {
 		return nil, err
 	}
-	return WrapPipelinePlans(bpSettings.BeforePlan, plan, bpSettings.AfterPlan)
-}
-
-// WrapPipelinePlans merges multiple pipelines and append before and after pipeline
-func WrapPipelinePlans(beforePlanJson json.RawMessage, mainPlan plugin.PipelinePlan, afterPlanJson json.RawMessage) (plugin.PipelinePlan, errors.Error) {
-	beforePipelinePlan := plugin.PipelinePlan{}
-	afterPipelinePlan := plugin.PipelinePlan{}
-
-	if beforePlanJson != nil {
-		err := errors.Convert(json.Unmarshal(beforePlanJson, &beforePipelinePlan))
-		if err != nil {
-			return nil, err
-		}
-	}
-	if afterPlanJson != nil {
-		err := errors.Convert(json.Unmarshal(afterPlanJson, &afterPipelinePlan))
-		if err != nil {
-			return nil, err
-		}
-	}
-
-	return SequencializePipelinePlans(beforePipelinePlan, mainPlan, afterPipelinePlan), nil
+	return SequencializePipelinePlans(blueprint.BeforePlan, plan, blueprint.AfterPlan), nil
 }
 
 // ParallelizePipelinePlans merges multiple pipelines into one unified plan
 // by assuming they can be executed in parallel
-func ParallelizePipelinePlans(plans ...plugin.PipelinePlan) plugin.PipelinePlan {
-	merged := make(plugin.PipelinePlan, 0)
+func ParallelizePipelinePlans(plans ...models.PipelinePlan) models.PipelinePlan {
+	merged := make(models.PipelinePlan, 0)
 	// iterate all pipelineTasks and try to merge them into `merged`
 	for _, plan := range plans {
 		// add all stages from plan to merged
@@ -396,8 +390,8 @@ func ParallelizePipelinePlans(plans ...plugin.PipelinePlan) plugin.PipelinePlan
 
 // SequencializePipelinePlans merges multiple pipelines into one unified plan
 // by assuming they must be executed in sequencial order
-func SequencializePipelinePlans(plans ...plugin.PipelinePlan) plugin.PipelinePlan {
-	merged := make(plugin.PipelinePlan, 0)
+func SequencializePipelinePlans(plans ...models.PipelinePlan) models.PipelinePlan {
+	merged := make(models.PipelinePlan, 0)
 	// iterate all pipelineTasks and try to merge them into `merged`
 	for _, plan := range plans {
 		merged = append(merged, plan...)
@@ -406,12 +400,26 @@ func SequencializePipelinePlans(plans ...plugin.PipelinePlan) plugin.PipelinePla
 }
 
 // TriggerBlueprint triggers blueprint immediately
-func TriggerBlueprint(id uint64, skipCollectors bool) (*models.Pipeline, errors.Error) {
+func TriggerBlueprint(id uint64, syncPolicy *models.SyncPolicy, shouldSanitize bool) (*models.Pipeline, errors.Error) {
 	// load record from db
-	blueprint, err := GetBlueprint(id)
+	blueprint, err := GetBlueprint(id, false)
 	if err != nil {
 		logger.Error(err, "GetBlueprint, id: %d", id)
 		return nil, err
 	}
-	return createPipelineByBlueprint(blueprint, skipCollectors)
+	if !blueprint.Enable {
+		return nil, errors.BadInput.New("blueprint is not enabled")
+	}
+	blueprint.SkipCollectors = syncPolicy.SkipCollectors
+	blueprint.FullSync = syncPolicy.FullSync
+	pipeline, err := createPipelineByBlueprint(blueprint, syncPolicy)
+	if err != nil {
+		return nil, err
+	}
+	if shouldSanitize {
+		if err := SanitizePipeline(pipeline); err != nil {
+			return nil, errors.Convert(err)
+		}
+	}
+	return pipeline, nil
 }
