@@ -20,7 +20,6 @@ package services
 import (
 	"context"
 	"fmt"
-	"regexp"
 	"strings"
 
 	"github.com/apache/incubator-devlake/core/dal"
@@ -31,7 +30,6 @@ import (
 )
 
 var taskLog = logruslog.Global.Nested("task service")
-var activityPattern = regexp.MustCompile(`task #(\d+)`)
 
 // TaskQuery FIXME .
 type TaskQuery struct {
@@ -42,8 +40,7 @@ type TaskQuery struct {
 	Pending    int    `form:"pending"`
 }
 
-// CreateTask creates a new task
-func CreateTask(newTask *models.NewTask) (*models.Task, errors.Error) {
+func createTask(newTask *models.NewTask, tx dal.Transaction) (*models.Task, errors.Error) {
 	task := &models.Task{
 		Plugin:      newTask.Plugin,
 		Subtasks:    newTask.Subtasks,
@@ -57,7 +54,7 @@ func CreateTask(newTask *models.NewTask) (*models.Task, errors.Error) {
 	if newTask.IsRerun {
 		task.Status = models.TASK_RERUN
 	}
-	err := db.Create(task)
+	err := tx.Create(task)
 	if err != nil {
 		taskLog.Error(err, "save task failed")
 		return nil, errors.Internal.Wrap(err, "save task failed")
@@ -113,9 +110,12 @@ func GetTasks(query *TaskQuery) ([]*models.Task, int64, errors.Error) {
 
 // GetTasksWithLastStatus returns task list of the pipeline, only the most recently tasks would be returned
 // TODO: adopts GetLatestTasksOfPipeline
-func GetTasksWithLastStatus(pipelineId uint64) ([]*models.Task, errors.Error) {
+func GetTasksWithLastStatus(pipelineId uint64, shouldSanitize bool, tx dal.Dal) ([]*models.Task, errors.Error) {
+	if tx == nil {
+		tx = db
+	}
 	var tasks []*models.Task
-	err := db.All(&tasks, dal.Where("pipeline_id = ?", pipelineId), dal.Orderby("id DESC"))
+	err := tx.All(&tasks, dal.Where("pipeline_id = ?", pipelineId), dal.Orderby("id DESC"))
 	if err != nil {
 		return nil, err
 	}
@@ -130,13 +130,22 @@ func GetTasksWithLastStatus(pipelineId uint64) ([]*models.Task, errors.Error) {
 			maxCol = task.PipelineCol
 		}
 	}
+
 	for _, task := range tasks {
 		index := int64(task.PipelineRow)*int64(maxCol) + int64(task.PipelineCol)
+		if shouldSanitize {
+			taskOption, err := SanitizePluginOption(task.Plugin, task.Options)
+			if err != nil {
+				return nil, errors.Convert(err)
+			}
+			task.Options = taskOption
+		}
 		if _, ok := taskIds[index]; !ok {
 			taskIds[index] = struct{}{}
 			result = append(result, task)
 		}
 	}
+
 	runningTasks.FillProgressDetailToTasks(result)
 	return result, nil
 }
@@ -219,5 +228,11 @@ func RerunTask(taskId uint64) (*models.Task, errors.Error) {
 	if err != nil {
 		return nil, err
 	}
-	return rerunTasks[0], nil
+	rerunTask := rerunTasks[0]
+	taskOption, sanitizePluginOptionErr := SanitizePluginOption(rerunTask.Plugin, rerunTask.Options)
+	if sanitizePluginOptionErr != nil {
+		return nil, errors.Convert(err)
+	}
+	rerunTask.Options = taskOption
+	return rerunTask, nil
 }
