@@ -16,5 +16,5 @@
  *
  */
 
+export * from './copy-text';
 export * from './external-link';
-export * from './icon-button';
