@@ -17,20 +17,12 @@
  */
 
 export * from './action';
-export * from './alert';
-export * from './buttons';
-export * from './card';
-export * from './dialog';
-export * from './divider';
-export * from './form';
+export * from './block';
 export * from './inspector';
 export * from './loading';
 export * from './logo';
 export * from './message';
 export * from './no-data';
 export * from './page-header';
-export * from './pagination';
-export * from './selector';
-export * from './table';
-export * from './toast';
+export * from './tip-layout';
 export * from './tooltip';
