@@ -15,28 +15,12 @@
  * limitations under the License.
  *
  */
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
 
 import { useState, useEffect } from 'react';
-import { FormGroup, RadioGroup, Radio, InputGroup } from '@blueprintjs/core';
+import type { RadioChangeEvent } from 'antd';
+import { Radio, Input } from 'antd';
 
-import * as S from './styled';
+import { Block } from '@/components';
 
 type VersionType = 'cloud' | 'server';
 
@@ -73,8 +57,8 @@ export const ConnectionEndpoint = ({
     setError(value ? '' : 'endpoint is required');
   }, [value]);
 
-  const handleChange = (e: React.FormEvent<HTMLInputElement>) => {
-    const version = (e.target as HTMLInputElement).value as VersionType;
+  const handleChange = (e: RadioChangeEvent) => {
+    const version = e.target.value;
     if (version === 'cloud') {
       setValue(multipleVersions?.cloud ?? '');
     }
@@ -92,42 +76,45 @@ export const ConnectionEndpoint = ({
 
   if (multipleVersions) {
     return (
-      <FormGroup label={<S.Label>{name} Version</S.Label>} labelInfo={<S.LabelInfo>*</S.LabelInfo>}>
-        <RadioGroup inline selectedValue={version} onChange={handleChange}>
-          <Radio value="cloud">{name} Cloud</Radio>
-          <Radio value="server" disabled={!multipleVersions.server}>
-            {name} Server {multipleVersions.server ? multipleVersions.server : '(to be supported)'}
-          </Radio>
-        </RadioGroup>
+      <>
+        <Block title={name} required>
+          <Radio.Group value={version} onChange={handleChange}>
+            <Radio value="cloud">{name} Cloud</Radio>
+            <Radio value="server" disabled={!multipleVersions.server}>
+              {name} Server {multipleVersions.server ? multipleVersions.server : '(to be supported)'}
+            </Radio>
+          </Radio.Group>
+        </Block>
         {version === 'cloud' && (
-          <p style={{ margin: 0 }}>
-            If you are using {name} Cloud, you do not need to enter the endpoint URL, which is {multipleVersions.cloud}.
-          </p>
+          <Block>
+            <p>
+              If you are using {name} Cloud, you do not need to enter the endpoint URL, which is{' '}
+              {multipleVersions.cloud}.
+            </p>
+          </Block>
         )}
         {version === 'server' && (
-          <FormGroup
-            label={<S.Label>Endpoint URL</S.Label>}
-            labelInfo={<S.LabelInfo>*</S.LabelInfo>}
-            subLabel={
-              <S.LabelDescription>
-                {subLabel ?? `If you are using ${name} Server, please enter the endpoint URL.`}
-              </S.LabelDescription>
-            }
+          <Block
+            title="Endpoint URL"
+            description={subLabel ?? `If you are using ${name} Server, please enter the endpoint URL.`}
+            required
           >
-            <InputGroup placeholder="Your Endpoint URL" value={value} onChange={handleChangeValue} />
-          </FormGroup>
+            <Input style={{ width: 386 }} placeholder="Your Endpoint URL" value={value} onChange={handleChangeValue} />
+          </Block>
         )}
-      </FormGroup>
+      </>
     );
   }
 
   return (
-    <FormGroup
-      label={<S.Label>Endpoint URL</S.Label>}
-      labelInfo={<S.LabelInfo>*</S.LabelInfo>}
-      subLabel={<S.LabelDescription>{subLabel ?? `Provide the ${name} instance API endpoint.`}</S.LabelDescription>}
-    >
-      <InputGroup disabled={disabled} placeholder="Your Endpoint URL" value={value} onChange={handleChangeValue} />
-    </FormGroup>
+    <Block title="Endpoint URL" description={subLabel ?? `Provide the ${name} instance API endpoint.`} required>
+      <Input
+        style={{ width: 386 }}
+        disabled={disabled}
+        placeholder="Your Endpoint URL"
+        value={value}
+        onChange={handleChangeValue}
+      />
+    </Block>
   );
 };
