@@ -18,10 +18,11 @@
 
 import { useState, useEffect, useMemo } from 'react';
 import { omit } from 'lodash';
-import { InputGroup, Button, Intent } from '@blueprintjs/core';
+import { Flex, Form, Input, Card, Alert, Divider, Select, Button } from 'antd';
 
-import { Alert, ExternalLink, Card, FormItem, MultiSelector, Message, Buttons, Divider } from '@/components';
-import { transformEntities, EntitiesLabel } from '@/config';
+import API from '@/api';
+import { ExternalLink, Block, Message } from '@/components';
+import { transformEntities } from '@/config';
 import { getPluginConfig } from '@/plugins';
 import { GitHubTransformation } from '@/plugins/register/github';
 import { JiraTransformation } from '@/plugins/register/jira';
@@ -31,16 +32,15 @@ import { BitbucketTransformation } from '@/plugins/register/bitbucket';
 import { AzureTransformation } from '@/plugins/register/azure';
 import { TapdTransformation } from '@/plugins/register/tapd';
 import { BambooTransformation } from '@/plugins/register/bamboo';
+import { CircleCITransformation } from '@/plugins/register/circleci';
 import { operator } from '@/utils';
 
-import { AdditionalSettings } from './fields';
 import { TIPS_MAP } from './misc';
-import * as API from './api';
-import * as S from './styled';
 
 interface Props {
   plugin: string;
   connectionId: ID;
+  defaultName?: string;
   showWarning?: boolean;
   scopeId?: ID;
   scopeConfigId?: ID;
@@ -51,6 +51,7 @@ interface Props {
 export const ScopeConfigForm = ({
   plugin,
   connectionId,
+  defaultName,
   showWarning = false,
   scopeId,
   scopeConfigId,
@@ -58,16 +59,15 @@ export const ScopeConfigForm = ({
   onSubmit,
 }: Props) => {
   const [step, setStep] = useState(1);
-  const [name, setName] = useState('');
+  const [name, setName] = useState(defaultName);
   const [entities, setEntities] = useState<string[]>([]);
   const [transformation, setTransformation] = useState<any>({});
-  const [hasRefDiff, setHasRefDiff] = useState(false);
+  const [hasError, setHasError] = useState(false);
   const [operating, setOperating] = useState(false);
 
   const config = useMemo(() => getPluginConfig(plugin), []);
 
   useEffect(() => {
-    setHasRefDiff(!!config.scopeConfig?.transformation.refdiff);
     setTransformation(config.scopeConfig?.transformation ?? {});
   }, [config.scopeConfig?.transformation]);
 
@@ -80,7 +80,7 @@ export const ScopeConfigForm = ({
 
     (async () => {
       try {
-        const res = await API.getScopeConfig(plugin, connectionId, scopeConfigId);
+        const res = await API.scopeConfig.get(plugin, connectionId, scopeConfigId);
         setName(res.name);
         setEntities(res.entities ?? []);
         setTransformation(omit(res, ['id', 'connectionId', 'name', 'entities', 'createdAt', 'updatedAt']));
@@ -100,8 +100,8 @@ export const ScopeConfigForm = ({
     const [success, res] = await operator(
       () =>
         !scopeConfigId
-          ? API.createScopeConfig(plugin, connectionId, { name, entities, ...transformation })
-          : API.updateScopeConfig(plugin, connectionId, scopeConfigId, { name, entities, ...transformation }),
+          ? API.scopeConfig.create(plugin, connectionId, { name, entities, ...transformation })
+          : API.scopeConfig.update(plugin, connectionId, scopeConfigId, { name, entities, ...transformation }),
       {
         setOperating,
         formatMessage: () => (!scopeConfigId ? 'Create scope config successful.' : 'Update scope config successful'),
@@ -114,11 +114,10 @@ export const ScopeConfigForm = ({
   };
 
   return (
-    <S.Wrapper>
+    <Flex vertical gap="middle">
       {TIPS_MAP[plugin] && (
         <Alert
-          style={{ marginBottom: 24 }}
-          content={
+          message={
             <>
               To learn about how {TIPS_MAP[plugin].name} transformation is used in DevLake,{' '}
               <ExternalLink link={TIPS_MAP[plugin].link}>check out this doc</ExternalLink>.
@@ -129,18 +128,18 @@ export const ScopeConfigForm = ({
       {step === 1 && (
         <>
           <Card>
-            <FormItem
-              label="Scope Config Name"
-              subLabel="Give this Scope Config a unique name so that you can identify it in the future."
+            <Block
+              title="Scope Config Name"
+              description="Give this Scope Config a unique name so that you can identify it in the future."
               required
             >
-              <InputGroup placeholder="My Scope Config 1" value={name} onChange={(e) => setName(e.target.value)} />
-            </FormItem>
+              <Input placeholder="My Scope Config 1" value={name} onChange={(e) => setName(e.target.value)} />
+            </Block>
           </Card>
           <Card>
-            <FormItem
-              label="Data Entities"
-              subLabel={
+            <Block
+              title="Data Entities"
+              description={
                 <>
                   Select the data entities you wish to collect for the Data Scope.
                   <ExternalLink link="">Learn about data entities</ExternalLink>
@@ -148,14 +147,14 @@ export const ScopeConfigForm = ({
               }
               required
             >
-              <MultiSelector
-                items={transformEntities(config.scopeConfig?.entities ?? [])}
-                getKey={(it) => it.value}
-                getName={(it) => it.label}
-                selectedItems={entities.map((it) => ({ label: EntitiesLabel[it], value: it }))}
-                onChangeItems={(its) => setEntities(its.map((it) => it.value))}
+              <Select
+                style={{ width: '100%' }}
+                mode="multiple"
+                options={transformEntities(config.scopeConfig?.entities ?? [])}
+                value={entities}
+                onChange={(value) => setEntities(value)}
               />
-            </FormItem>
+            </Block>
             {showWarning && (
               <Message
                 content="Please note: if you edit Data Entities and expect to see the Dashboards updated, you will need to visit
@@ -164,15 +163,17 @@ export const ScopeConfigForm = ({
               />
             )}
           </Card>
-          <Buttons position="bottom" align="right">
-            <Button outlined intent={Intent.PRIMARY} text="Cancel" onClick={onCancel} />
-            <Button disabled={!name || !entities.length} intent={Intent.PRIMARY} text="Next" onClick={handleNextStep} />
-          </Buttons>
+          <Flex justify="flex-end" gap="small">
+            <Button onClick={onCancel}>Cancel</Button>
+            <Button type="primary" disabled={!name || !entities.length} onClick={handleNextStep}>
+              Next
+            </Button>
+          </Flex>
         </>
       )}
       {step === 2 && (
         <>
-          <Card style={{ margin: 0 }}>
+          <Card>
             <h1 style={{ marginBottom: 16 }}>Transformations</h1>
             <Divider />
             {showWarning && (
@@ -182,81 +183,93 @@ export const ScopeConfigForm = ({
               />
             )}
 
-            {plugin === 'github' && (
-              <GitHubTransformation
-                entities={entities}
-                transformation={transformation}
-                setTransformation={setTransformation}
-              />
-            )}
+            <Form labelCol={{ span: 4 }} wrapperCol={{ span: 16 }}>
+              {plugin === 'azuredevops' && (
+                <AzureTransformation
+                  entities={entities}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                />
+              )}
 
-            {plugin === 'jira' && (
-              <JiraTransformation
-                entities={entities}
-                connectionId={connectionId}
-                transformation={transformation}
-                setTransformation={setTransformation}
-              />
-            )}
+              {plugin === 'bamboo' && (
+                <BambooTransformation
+                  entities={entities}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                />
+              )}
 
-            {plugin === 'gitlab' && (
-              <GitLabTransformation
-                entities={entities}
-                transformation={transformation}
-                setTransformation={setTransformation}
-              />
-            )}
+              {plugin === 'bitbucket' && (
+                <BitbucketTransformation
+                  entities={entities}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                />
+              )}
 
-            {plugin === 'jenkins' && (
-              <JenkinsTransformation
-                entities={entities}
-                transformation={transformation}
-                setTransformation={setTransformation}
-              />
-            )}
+              {plugin === 'circleci' && (
+                <CircleCITransformation
+                  entities={entities}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                />
+              )}
 
-            {plugin === 'bitbucket' && (
-              <BitbucketTransformation
-                entities={entities}
-                transformation={transformation}
-                setTransformation={setTransformation}
-              />
-            )}
+              {plugin === 'github' && (
+                <GitHubTransformation
+                  entities={entities}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                  setHasError={setHasError}
+                />
+              )}
 
-            {plugin === 'azuredevops' && (
-              <AzureTransformation
-                entities={entities}
-                transformation={transformation}
-                setTransformation={setTransformation}
-              />
-            )}
+              {plugin === 'gitlab' && (
+                <GitLabTransformation
+                  entities={entities}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                  setHasError={setHasError}
+                />
+              )}
 
-            {plugin === 'tapd' && scopeId && (
-              <TapdTransformation
-                entities={entities}
-                connectionId={connectionId}
-                scopeId={scopeId}
-                transformation={transformation}
-                setTransformation={setTransformation}
-              />
-            )}
+              {plugin === 'jenkins' && (
+                <JenkinsTransformation
+                  entities={entities}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                />
+              )}
 
-            {plugin === 'bamboo' && (
-              <BambooTransformation
-                entities={entities}
-                transformation={transformation}
-                setTransformation={setTransformation}
-              />
-            )}
+              {plugin === 'jira' && (
+                <JiraTransformation
+                  entities={entities}
+                  connectionId={connectionId}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                />
+              )}
 
-            {hasRefDiff && <AdditionalSettings transformation={transformation} setTransformation={setTransformation} />}
+              {plugin === 'tapd' && scopeId && (
+                <TapdTransformation
+                  entities={entities}
+                  connectionId={connectionId}
+                  scopeId={scopeId}
+                  transformation={transformation}
+                  setTransformation={setTransformation}
+                />
+              )}
+            </Form>
           </Card>
-          <Buttons position="bottom" align="right">
-            <Button outlined intent={Intent.PRIMARY} text="Prev" onClick={handlePrevStep} />
-            <Button loading={operating} intent={Intent.PRIMARY} text="Save" onClick={handleSubmit} />
-          </Buttons>
+          <Flex justify="flex-end" gap="small">
+            <Button onClick={handlePrevStep}>Prev</Button>
+            <Button type="primary" loading={operating} disabled={hasError} onClick={handleSubmit}>
+              Save
+            </Button>
+          </Flex>
         </>
       )}
-    </S.Wrapper>
+    </Flex>
   );
 };
