@@ -18,19 +18,16 @@
 
 import { ExternalLink } from '@/components';
 import { DOC_URL } from '@/release';
+import { IPluginConfig } from '@/types';
 
-import type { PluginConfigType } from '../../types';
-import { PluginType } from '../../types';
-
-import Icon from './assets/icon.svg';
+import Icon from './assets/icon.svg?react';
 import { BaseURL } from './connection-fields';
 
-export const AzureConfig: PluginConfigType = {
-  type: PluginType.Connection,
+export const AzureConfig: IPluginConfig = {
   plugin: 'azuredevops',
   name: 'Azure DevOps',
-  icon: Icon,
-  sort: 6,
+  icon: ({ color }) => <Icon fill={color} />,
+  sort: 1,
   connection: {
     docLink: DOC_URL.PLUGIN.AZUREDEVOPS.BASIS,
     fields: [
@@ -58,9 +55,10 @@ export const AzureConfig: PluginConfigType = {
     ],
   },
   dataScope: {
-    millerColumns: {
-      title: 'Add Repositories by Selecting from the Directory',
-      subTitle: 'The following directory lists out all repositories in your organizations.',
+    localSearch: true,
+    title: 'Repositories',
+    millerColumn: {
+      columnCount: 2,
     },
   },
   scopeConfig: {
