@@ -19,10 +19,13 @@
 import path from 'path';
 import { defineConfig } from 'vite';
 import react from '@vitejs/plugin-react';
+import svgr from 'vite-plugin-svgr';
 
 // https://vitejs.dev/config/
 export default defineConfig({
-  plugins: [react()],
+  plugins: [svgr(), react()],
+
+  envPrefix: 'DEVLAKE_',
 
   server: {
     port: 4000,
@@ -30,7 +33,7 @@ export default defineConfig({
       '/api': {
         target: 'http://localhost:8080/',
         changeOrigin: true,
-        rewrite: (path) => path.replace(/^\/api/, ''),
+        rewrite: (path) => path.replace(/^\/api\//, ''),
       },
     },
   },
